# flake8: noqa
# import models into model package
from timestep.api.ap.v1.models.artifact import Artifact
from timestep.api.ap.v1.models.get_agent_task404_response import GetAgentTask404Response
from timestep.api.ap.v1.models.pagination import Pagination
from timestep.api.ap.v1.models.step import Step
from timestep.api.ap.v1.models.step_request_body import StepRequestBody
from timestep.api.ap.v1.models.task import Task
from timestep.api.ap.v1.models.task_artifacts_list_response import (
    TaskArtifactsListResponse,
)
from timestep.api.ap.v1.models.task_list_response import TaskListResponse
from timestep.api.ap.v1.models.task_request_body import TaskRequestBody
from timestep.api.ap.v1.models.task_steps_list_response import TaskStepsListResponse



from typing import Dict, Tuple, Union

import connexion

from timestep.api.openai.v1 import util
from timestep.api.openai.v1.models.batch import Batch  # noqa: E501
from timestep.api.openai.v1.models.create_batch_request import (  # noqa: E501
    CreateBatchRequest,
)
from timestep.api.openai.v1.models.list_batches_response import (  # noqa: E501
    ListBatchesResponse,
)


def cancel_batch(batch_id):  # noqa: E501
    """Cancels an in-progress batch. The batch will be in status &#x60;cancelling&#x60; for up to 10 minutes, before changing to &#x60;cancelled&#x60;, where it will have partial results (if any) available in the output file.

     # noqa: E501

    :param batch_id: The ID of the batch to cancel.
    :type batch_id: str

    :rtype: Union[Batch, Tuple[Batch, int], Tuple[Batch, int, Dict[str, str]]
    """
    raise NotImplementedError


def create_batch(create_batch_request):  # noqa: E501
    """Creates and executes a batch from an uploaded file of requests

     # noqa: E501

    :param create_batch_request:
    :type create_batch_request: dict | bytes

    :rtype: Union[Batch, Tuple[Batch, int], Tuple[Batch, int, Dict[str, str]]
    """
    if connexion.request.is_json:
        create_batch_request = CreateBatchRequest.from_dict(
            connexion.request.get_json()
        )  # noqa: E501
    raise NotImplementedError


def list_batches(after=None, limit=None):  # noqa: E501
    """List your organization&#39;s batches.

     # noqa: E501

    :param after: A cursor for use in pagination. &#x60;after&#x60; is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with obj_foo, your subsequent call can include after&#x3D;obj_foo in order to fetch the next page of the list.
    :type after: str
    :param limit: A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 20.
    :type limit: int

    :rtype: Union[ListBatchesResponse, Tuple[ListBatchesResponse, int], Tuple[ListBatchesResponse, int, Dict[str, str]]
    """
    raise NotImplementedError


def retrieve_batch(batch_id):  # noqa: E501
    """Retrieves a batch.

     # noqa: E501

    :param batch_id: The ID of the batch to retrieve.
    :type batch_id: str

    :rtype: Union[Batch, Tuple[Batch, int], Tuple[Batch, int, Dict[str, str]]
    """
    raise NotImplementedError



from typing import Dict, Tuple, Union

import connexion

from timestep.api.openai.v1 import util
from timestep.api.openai.v1.models.create_moderation_request import (  # noqa: E501
    CreateModerationRequest,
)
from timestep.api.openai.v1.models.create_moderation_response import (  # noqa: E501
    CreateModerationResponse,
)


def create_moderation(create_moderation_request):  # noqa: E501
    """Classifies if text is potentially harmful.

     # noqa: E501

    :param create_moderation_request:
    :type create_moderation_request: dict | bytes

    :rtype: Union[CreateModerationResponse, Tuple[CreateModerationResponse, int], Tuple[CreateModerationResponse, int, Dict[str, str]]
    """
    if connexion.request.is_json:
        create_moderation_request = CreateModerationRequest.from_dict(
            connexion.request.get_json()
        )  # noqa: E501
    raise NotImplementedError



from datetime import date, datetime  # noqa: F401
from typing import Dict, List  # noqa: F401

from timestep.api.ap.v1 import util
from timestep.api.ap.v1.models.base_model import Model
from timestep.api.ap.v1.models.pagination import Pagination  # noqa: E501
from timestep.api.ap.v1.models.step import Step  # noqa: E501


class TaskStepsListResponse(Model):
    """NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).

    Do not edit the class manually.
    """

    def __init__(self, steps=None, pagination=None):  # noqa: E501
        """TaskStepsListResponse - a model defined in OpenAPI

        :param steps: The steps of this TaskStepsListResponse.  # noqa: E501
        :type steps: List[Step]
        :param pagination: The pagination of this TaskStepsListResponse.  # noqa: E501
        :type pagination: Pagination
        """
        self.openapi_types = {"steps": List[Step], "pagination": Pagination}

        self.attribute_map = {"steps": "steps", "pagination": "pagination"}

        self._steps = steps
        self._pagination = pagination

    @classmethod
    def from_dict(cls, dikt) -> "TaskStepsListResponse":
        """Returns the dict as a model

        :param dikt: A dict.
        :type: dict
        :return: The TaskStepsListResponse of this TaskStepsListResponse.  # noqa: E501
        :rtype: TaskStepsListResponse
        """
        return util.deserialize_model(dikt, cls)

    @property
    def steps(self) -> List[Step]:
        """Gets the steps of this TaskStepsListResponse.


        :return: The steps of this TaskStepsListResponse.
        :rtype: List[Step]
        """
        return self._steps

    @steps.setter
    def steps(self, steps: List[Step]):
        """Sets the steps of this TaskStepsListResponse.


        :param steps: The steps of this TaskStepsListResponse.
        :type steps: List[Step]
        """
        if steps is None:
            raise ValueError(
                "Invalid value for `steps`, must not be `None`"
            )  # noqa: E501

        self._steps = steps

    @property
    def pagination(self) -> Pagination:
        """Gets the pagination of this TaskStepsListResponse.


        :return: The pagination of this TaskStepsListResponse.
        :rtype: Pagination
        """
        return self._pagination

    @pagination.setter
    def pagination(self, pagination: Pagination):
        """Sets the pagination of this TaskStepsListResponse.


        :param pagination: The pagination of this TaskStepsListResponse.
        :type pagination: Pagination
        """
        if pagination is None:
            raise ValueError(
                "Invalid value for `pagination`, must not be `None`"
            )  # noqa: E501

        self._pagination = pagination



from datetime import date, datetime  # noqa: F401
from typing import Dict, List  # noqa: F401

from timestep.api.ap.v1 import util
from timestep.api.ap.v1.models.artifact import Artifact  # noqa: E501
from timestep.api.ap.v1.models.base_model import Model


class Task(Model):
    """NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).

    Do not edit the class manually.
    """

    def __init__(
        self, input=None, additional_input=None, task_id=None, artifacts=[]
    ):  # noqa: E501
        """Task - a model defined in OpenAPI

        :param input: The input of this Task.  # noqa: E501
        :type input: str
        :param additional_input: The additional_input of this Task.  # noqa: E501
        :type additional_input: object
        :param task_id: The task_id of this Task.  # noqa: E501
        :type task_id: str
        :param artifacts: The artifacts of this Task.  # noqa: E501
        :type artifacts: List[Artifact]
        """
        self.openapi_types = {
            "input": str,
            "additional_input": object,
            "task_id": str,
            "artifacts": List[Artifact],
        }

        self.attribute_map = {
            "input": "input",
            "additional_input": "additional_input",
            "task_id": "task_id",
            "artifacts": "artifacts",
        }

        self._input = input
        self._additional_input = additional_input
        self._task_id = task_id
        self._artifacts = artifacts

    @classmethod
    def from_dict(cls, dikt) -> "Task":
        """Returns the dict as a model

        :param dikt: A dict.
        :type: dict
        :return: The Task of this Task.  # noqa: E501
        :rtype: Task
        """
        return util.deserialize_model(dikt, cls)

    @property
    def input(self) -> str:
        """Gets the input of this Task.

        Input prompt for the task.  # noqa: E501

        :return: The input of this Task.
        :rtype: str
        """
        return self._input

    @input.setter
    def input(self, input: str):
        """Sets the input of this Task.

        Input prompt for the task.  # noqa: E501

        :param input: The input of this Task.
        :type input: str
        """

        self._input = input

    @property
    def additional_input(self) -> object:
        """Gets the additional_input of this Task.

        Input parameters for the task. Any value is allowed.  # noqa: E501

        :return: The additional_input of this Task.
        :rtype: object
        """
        return self._additional_input

    @additional_input.setter
    def additional_input(self, additional_input: object):
        """Sets the additional_input of this Task.

        Input parameters for the task. Any value is allowed.  # noqa: E501

        :param additional_input: The additional_input of this Task.
        :type additional_input: object
        """

        self._additional_input = additional_input

    @property
    def task_id(self) -> str:
        """Gets the task_id of this Task.

        The ID of the task.  # noqa: E501

        :return: The task_id of this Task.
        :rtype: str
        """
        return self._task_id

    @task_id.setter
    def task_id(self, task_id: str):
        """Sets the task_id of this Task.

        The ID of the task.  # noqa: E501

        :param task_id: The task_id of this Task.
        :type task_id: str
        """
        if task_id is None:
            raise ValueError(
                "Invalid value for `task_id`, must not be `None`"
            )  # noqa: E501

        self._task_id = task_id

    @property
    def artifacts(self) -> List[Artifact]:
        """Gets the artifacts of this Task.

        A list of artifacts that the task has produced.  # noqa: E501

        :return: The artifacts of this Task.
        :rtype: List[Artifact]
        """
        return self._artifacts

    @artifacts.setter
    def artifacts(self, artifacts: List[Artifact]):
        """Sets the artifacts of this Task.

        A list of artifacts that the task has produced.  # noqa: E501

        :param artifacts: The artifacts of this Task.
        :type artifacts: List[Artifact]
        """
        if artifacts is None:
            raise ValueError(
                "Invalid value for `artifacts`, must not be `None`"
            )  # noqa: E501

        self._artifacts = artifacts



import unittest

from flask import json

from timestep.api.openai.v1.models.create_speech_request import (  # noqa: E501
    CreateSpeechRequest,
)
from timestep.api.openai.v1.models.create_transcription200_response import (  # noqa: E501
    CreateTranscription200Response,
)
from timestep.api.openai.v1.models.create_transcription_request_model import (  # noqa: E501
    CreateTranscriptionRequestModel,
)
from timestep.api.openai.v1.models.create_translation200_response import (  # noqa: E501
    CreateTranslation200Response,
)
from timestep.api.openai.v1.test import BaseTestCase


class TestAudioController(BaseTestCase):
    """AudioController integration test stubs"""

    def test_create_speech(self):
        """Test case for create_speech

        Generates audio from the input text.
        """
        create_speech_request = {
            "voice": "alloy",
            "input": "input",
            "response_format": "mp3",
            "model": "CreateSpeechRequest_model",
            "speed": 0.5503105714228793,
        }
        headers = {
            "Accept": "application/octet-stream",
            "Content-Type": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/audio/speech",
            method="POST",
            headers=headers,
            data=json.dumps(create_speech_request),
            content_type="application/json",
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    @unittest.skip("multipart/form-data not supported by Connexion")
    def test_create_transcription(self):
        """Test case for create_transcription

        Transcribes audio into the input language.
        """
        headers = {
            "Accept": "application/json",
            "Content-Type": "multipart/form-data",
            "Authorization": "Bearer special-key",
        }
        data = dict(
            file="/path/to/file",
            model=timestep.api.openai.v1.CreateTranscriptionRequestModel(),
            language="language_example",
            prompt="prompt_example",
            response_format=json,
            temperature=0,
            timestamp_granularities=["timestamp_granularities_example"],
        )
        response = self.client.open(
            "/v1/audio/transcriptions",
            method="POST",
            headers=headers,
            data=data,
            content_type="multipart/form-data",
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    @unittest.skip("multipart/form-data not supported by Connexion")
    def test_create_translation(self):
        """Test case for create_translation

        Translates audio into English.
        """
        headers = {
            "Accept": "application/json",
            "Content-Type": "multipart/form-data",
            "Authorization": "Bearer special-key",
        }
        data = dict(
            file="/path/to/file",
            model=timestep.api.openai.v1.CreateTranscriptionRequestModel(),
            prompt="prompt_example",
            response_format="json",
            temperature=0,
        )
        response = self.client.open(
            "/v1/audio/translations",
            method="POST",
            headers=headers,
            data=data,
            content_type="multipart/form-data",
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))


if __name__ == "__main__":
    unittest.main()



from datetime import date, datetime  # noqa: F401
from typing import Dict, List  # noqa: F401

from timestep.api.ap.v1 import util
from timestep.api.ap.v1.models.base_model import Model


class Pagination(Model):
    """NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).

    Do not edit the class manually.
    """

    def __init__(
        self, total_items=None, total_pages=None, current_page=None, page_size=None
    ):  # noqa: E501
        """Pagination - a model defined in OpenAPI

        :param total_items: The total_items of this Pagination.  # noqa: E501
        :type total_items: int
        :param total_pages: The total_pages of this Pagination.  # noqa: E501
        :type total_pages: int
        :param current_page: The current_page of this Pagination.  # noqa: E501
        :type current_page: int
        :param page_size: The page_size of this Pagination.  # noqa: E501
        :type page_size: int
        """
        self.openapi_types = {
            "total_items": int,
            "total_pages": int,
            "current_page": int,
            "page_size": int,
        }

        self.attribute_map = {
            "total_items": "total_items",
            "total_pages": "total_pages",
            "current_page": "current_page",
            "page_size": "page_size",
        }

        self._total_items = total_items
        self._total_pages = total_pages
        self._current_page = current_page
        self._page_size = page_size

    @classmethod
    def from_dict(cls, dikt) -> "Pagination":
        """Returns the dict as a model

        :param dikt: A dict.
        :type: dict
        :return: The Pagination of this Pagination.  # noqa: E501
        :rtype: Pagination
        """
        return util.deserialize_model(dikt, cls)

    @property
    def total_items(self) -> int:
        """Gets the total_items of this Pagination.

        Total number of items.  # noqa: E501

        :return: The total_items of this Pagination.
        :rtype: int
        """
        return self._total_items

    @total_items.setter
    def total_items(self, total_items: int):
        """Sets the total_items of this Pagination.

        Total number of items.  # noqa: E501

        :param total_items: The total_items of this Pagination.
        :type total_items: int
        """
        if total_items is None:
            raise ValueError(
                "Invalid value for `total_items`, must not be `None`"
            )  # noqa: E501

        self._total_items = total_items

    @property
    def total_pages(self) -> int:
        """Gets the total_pages of this Pagination.

        Total number of pages.  # noqa: E501

        :return: The total_pages of this Pagination.
        :rtype: int
        """
        return self._total_pages

    @total_pages.setter
    def total_pages(self, total_pages: int):
        """Sets the total_pages of this Pagination.

        Total number of pages.  # noqa: E501

        :param total_pages: The total_pages of this Pagination.
        :type total_pages: int
        """
        if total_pages is None:
            raise ValueError(
                "Invalid value for `total_pages`, must not be `None`"
            )  # noqa: E501

        self._total_pages = total_pages

    @property
    def current_page(self) -> int:
        """Gets the current_page of this Pagination.

        Current_page page number.  # noqa: E501

        :return: The current_page of this Pagination.
        :rtype: int
        """
        return self._current_page

    @current_page.setter
    def current_page(self, current_page: int):
        """Sets the current_page of this Pagination.

        Current_page page number.  # noqa: E501

        :param current_page: The current_page of this Pagination.
        :type current_page: int
        """
        if current_page is None:
            raise ValueError(
                "Invalid value for `current_page`, must not be `None`"
            )  # noqa: E501

        self._current_page = current_page

    @property
    def page_size(self) -> int:
        """Gets the page_size of this Pagination.

        Number of items per page.  # noqa: E501

        :return: The page_size of this Pagination.
        :rtype: int
        """
        return self._page_size

    @page_size.setter
    def page_size(self, page_size: int):
        """Sets the page_size of this Pagination.

        Number of items per page.  # noqa: E501

        :param page_size: The page_size of this Pagination.
        :type page_size: int
        """
        if page_size is None:
            raise ValueError(
                "Invalid value for `page_size`, must not be `None`"
            )  # noqa: E501

        self._page_size = page_size



import uvicorn
from connexion import AsyncApp, ConnexionMiddleware
from connexion.options import SwaggerUIOptions
from fastapi import FastAPI, Request

connexion_app = AsyncApp(import_name=__name__)
fastapi_app = FastAPI()


def main():
    from timestep.api.openai.v1.controllers.completions_controller import (
        create_completion,
    )

    # from timestep.services import model_service

    connexion_app.add_api(
        "api/ap/v1/openapi/openapi.yaml",
        pythonic_params=True,
        resolver_error=501,
        swagger_ui_options=SwaggerUIOptions(serve_spec=False),
    )

    connexion_app.add_api(
        "api/openai/v1/openapi/openapi.yaml",
        base_path="/openai/v1",
        pythonic_params=True,
        resolver_error=501,
    )

    fastapi_app.mount(
        "/api", ConnexionMiddleware(app=connexion_app, import_name=__name__)
    )

    @fastapi_app.post("/v1/engines/{engine}/completions")
    async def create_code_completion(engine: str, request: Request):
        if engine == "copilot-codex":
            body = await request.json()
            body["model"] = "LLaMA_CPP"

            return await create_completion(body, token_info={}, user=None)

        else:
            raise NotImplementedError("Not implemented")

    # @fastapi_app.get("/v2/models/{model_id}")
    # async def create_code_completion(model_id: str, request: Request):
    #     # model_info = models_service.retrieve_model(model_id, token_info, user)
    #     model_info = model_service.retrieve_model(model_id)

    #     print("model_info: ", model_info)

    #     return model_info

    uvicorn.run(
        f"{__name__}:fastapi_app",
        host="0.0.0.0",
        log_level="info",
        loop="asyncio",
        port=8000,
        # reload=True,
        # reload_dirs=[
        #     f"{cwd}/api",
        # ],
        workers=1,
    )


if __name__ == "__main__":
    main()



import unittest

from flask import json

from timestep.api.openai.v1.models.create_moderation_request import (  # noqa: E501
    CreateModerationRequest,
)
from timestep.api.openai.v1.models.create_moderation_response import (  # noqa: E501
    CreateModerationResponse,
)
from timestep.api.openai.v1.test import BaseTestCase


class TestModerationsController(BaseTestCase):
    """ModerationsController integration test stubs"""

    def test_create_moderation(self):
        """Test case for create_moderation

        Classifies if text is potentially harmful.
        """
        create_moderation_request = {
            "input": "I want to kill them.",
            "model": "text-moderation-stable",
        }
        headers = {
            "Accept": "application/json",
            "Content-Type": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/moderations",
            method="POST",
            headers=headers,
            data=json.dumps(create_moderation_request),
            content_type="application/json",
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))


if __name__ == "__main__":
    unittest.main()



import unittest

from flask import json

from timestep.api.openai.v1.models.create_chat_completion_request import (  # noqa: E501
    CreateChatCompletionRequest,
)
from timestep.api.openai.v1.models.create_chat_completion_response import (  # noqa: E501
    CreateChatCompletionResponse,
)
from timestep.api.openai.v1.test import BaseTestCase


class TestChatController(BaseTestCase):
    """ChatController integration test stubs"""

    def test_create_chat_completion(self):
        """Test case for create_chat_completion

        Creates a model response for the given chat conversation.
        """
        create_chat_completion_request = {
            "top_logprobs": 2,
            "logit_bias": {"key": 6},
            "seed": -2147483648,
            "functions": [
                {
                    "name": "name",
                    "description": "description",
                    "parameters": {"key": ""},
                },
                {
                    "name": "name",
                    "description": "description",
                    "parameters": {"key": ""},
                },
                {
                    "name": "name",
                    "description": "description",
                    "parameters": {"key": ""},
                },
                {
                    "name": "name",
                    "description": "description",
                    "parameters": {"key": ""},
                },
                {
                    "name": "name",
                    "description": "description",
                    "parameters": {"key": ""},
                },
            ],
            "max_tokens": 5,
            "function_call": "none",
            "presence_penalty": 0.25495066265333133,
            "tools": [
                {
                    "function": {
                        "name": "name",
                        "description": "description",
                        "parameters": {"key": ""},
                    },
                    "type": "function",
                },
                {
                    "function": {
                        "name": "name",
                        "description": "description",
                        "parameters": {"key": ""},
                    },
                    "type": "function",
                },
            ],
            "n": 1,
            "logprobs": False,
            "top_p": 1,
            "frequency_penalty": -1.6796687238155954,
            "response_format": {"type": "json_object"},
            "stop": "CreateChatCompletionRequest_stop",
            "parallel_tool_calls": True,
            "stream": False,
            "temperature": 1,
            "messages": [
                {"role": "system", "name": "name", "content": "content"},
                {"role": "system", "name": "name", "content": "content"},
            ],
            "tool_choice": "none",
            "model": "gpt-4-turbo",
            "service_tier": "auto",
            "stream_options": {"include_usage": True},
            "user": "user-1234",
        }
        headers = {
            "Accept": "application/json",
            "Content-Type": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/chat/completions",
            method="POST",
            headers=headers,
            data=json.dumps(create_chat_completion_request),
            content_type="application/json",
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))


if __name__ == "__main__":
    unittest.main()



import unittest

from flask import json

from timestep.api.openai.v1.models.create_vector_store_file_batch_request import (  # noqa: E501
    CreateVectorStoreFileBatchRequest,
)
from timestep.api.openai.v1.models.create_vector_store_file_request import (  # noqa: E501
    CreateVectorStoreFileRequest,
)
from timestep.api.openai.v1.models.create_vector_store_request import (  # noqa: E501
    CreateVectorStoreRequest,
)
from timestep.api.openai.v1.models.delete_vector_store_file_response import (  # noqa: E501
    DeleteVectorStoreFileResponse,
)
from timestep.api.openai.v1.models.delete_vector_store_response import (  # noqa: E501
    DeleteVectorStoreResponse,
)
from timestep.api.openai.v1.models.list_vector_store_files_response import (  # noqa: E501
    ListVectorStoreFilesResponse,
)
from timestep.api.openai.v1.models.list_vector_stores_response import (  # noqa: E501
    ListVectorStoresResponse,
)
from timestep.api.openai.v1.models.update_vector_store_request import (  # noqa: E501
    UpdateVectorStoreRequest,
)
from timestep.api.openai.v1.models.vector_store_file_batch_object import (  # noqa: E501
    VectorStoreFileBatchObject,
)
from timestep.api.openai.v1.models.vector_store_file_object import (  # noqa: E501
    VectorStoreFileObject,
)
from timestep.api.openai.v1.models.vector_store_object import (  # noqa: E501
    VectorStoreObject,
)
from timestep.api.openai.v1.test import BaseTestCase


class TestVectorStoresController(BaseTestCase):
    """VectorStoresController integration test stubs"""

    def test_cancel_vector_store_file_batch(self):
        """Test case for cancel_vector_store_file_batch

        Cancel a vector store file batch. This attempts to cancel the processing of files in this batch as soon as possible.
        """
        headers = {
            "Accept": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/vector_stores/{vector_store_id}/file_batches/{batch_id}/cancel".format(
                vector_store_id="vector_store_id_example", batch_id="batch_id_example"
            ),
            method="POST",
            headers=headers,
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_create_vector_store(self):
        """Test case for create_vector_store

        Create a vector store.
        """
        create_vector_store_request = {
            "chunking_strategy": {"type": "auto"},
            "metadata": "{}",
            "expires_after": {"anchor": "last_active_at", "days": 339},
            "file_ids": ["file_ids", "file_ids", "file_ids", "file_ids", "file_ids"],
            "name": "name",
        }
        headers = {
            "Accept": "application/json",
            "Content-Type": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/vector_stores",
            method="POST",
            headers=headers,
            data=json.dumps(create_vector_store_request),
            content_type="application/json",
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_create_vector_store_file(self):
        """Test case for create_vector_store_file

        Create a vector store file by attaching a [File](/docs/api-reference/files) to a [vector store](/docs/api-reference/vector-stores/object).
        """
        create_vector_store_file_request = {
            "chunking_strategy": {"type": "auto"},
            "file_id": "file_id",
        }
        headers = {
            "Accept": "application/json",
            "Content-Type": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/vector_stores/{vector_store_id}/files".format(
                vector_store_id="vs_abc123"
            ),
            method="POST",
            headers=headers,
            data=json.dumps(create_vector_store_file_request),
            content_type="application/json",
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_create_vector_store_file_batch(self):
        """Test case for create_vector_store_file_batch

        Create a vector store file batch.
        """
        create_vector_store_file_batch_request = {
            "chunking_strategy": {"type": "auto"},
            "file_ids": ["file_ids", "file_ids", "file_ids", "file_ids", "file_ids"],
        }
        headers = {
            "Accept": "application/json",
            "Content-Type": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/vector_stores/{vector_store_id}/file_batches".format(
                vector_store_id="vs_abc123"
            ),
            method="POST",
            headers=headers,
            data=json.dumps(create_vector_store_file_batch_request),
            content_type="application/json",
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_delete_vector_store(self):
        """Test case for delete_vector_store

        Delete a vector store.
        """
        headers = {
            "Accept": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/vector_stores/{vector_store_id}".format(
                vector_store_id="vector_store_id_example"
            ),
            method="DELETE",
            headers=headers,
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_delete_vector_store_file(self):
        """Test case for delete_vector_store_file

        Delete a vector store file. This will remove the file from the vector store but the file itself will not be deleted. To delete the file, use the [delete file](/docs/api-reference/files/delete) endpoint.
        """
        headers = {
            "Accept": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/vector_stores/{vector_store_id}/files/{file_id}".format(
                vector_store_id="vector_store_id_example", file_id="file_id_example"
            ),
            method="DELETE",
            headers=headers,
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_get_vector_store(self):
        """Test case for get_vector_store

        Retrieves a vector store.
        """
        headers = {
            "Accept": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/vector_stores/{vector_store_id}".format(
                vector_store_id="vector_store_id_example"
            ),
            method="GET",
            headers=headers,
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_get_vector_store_file(self):
        """Test case for get_vector_store_file

        Retrieves a vector store file.
        """
        headers = {
            "Accept": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/vector_stores/{vector_store_id}/files/{file_id}".format(
                vector_store_id="vs_abc123", file_id="file-abc123"
            ),
            method="GET",
            headers=headers,
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_get_vector_store_file_batch(self):
        """Test case for get_vector_store_file_batch

        Retrieves a vector store file batch.
        """
        headers = {
            "Accept": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/vector_stores/{vector_store_id}/file_batches/{batch_id}".format(
                vector_store_id="vs_abc123", batch_id="vsfb_abc123"
            ),
            method="GET",
            headers=headers,
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_list_files_in_vector_store_batch(self):
        """Test case for list_files_in_vector_store_batch

        Returns a list of vector store files in a batch.
        """
        query_string = [
            ("limit", 20),
            ("order", desc),
            ("after", "after_example"),
            ("before", "before_example"),
            ("filter", "filter_example"),
        ]
        headers = {
            "Accept": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/vector_stores/{vector_store_id}/file_batches/{batch_id}/files".format(
                vector_store_id="vector_store_id_example", batch_id="batch_id_example"
            ),
            method="GET",
            headers=headers,
            query_string=query_string,
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_list_vector_store_files(self):
        """Test case for list_vector_store_files

        Returns a list of vector store files.
        """
        query_string = [
            ("limit", 20),
            ("order", desc),
            ("after", "after_example"),
            ("before", "before_example"),
            ("filter", "filter_example"),
        ]
        headers = {
            "Accept": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/vector_stores/{vector_store_id}/files".format(
                vector_store_id="vector_store_id_example"
            ),
            method="GET",
            headers=headers,
            query_string=query_string,
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_list_vector_stores(self):
        """Test case for list_vector_stores

        Returns a list of vector stores.
        """
        query_string = [
            ("limit", 20),
            ("order", desc),
            ("after", "after_example"),
            ("before", "before_example"),
        ]
        headers = {
            "Accept": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/vector_stores",
            method="GET",
            headers=headers,
            query_string=query_string,
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_modify_vector_store(self):
        """Test case for modify_vector_store

        Modifies a vector store.
        """
        update_vector_store_request = {
            "metadata": "{}",
            "expires_after": {"anchor": "last_active_at", "days": 339},
            "name": "name",
        }
        headers = {
            "Accept": "application/json",
            "Content-Type": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/vector_stores/{vector_store_id}".format(
                vector_store_id="vector_store_id_example"
            ),
            method="POST",
            headers=headers,
            data=json.dumps(update_vector_store_request),
            content_type="application/json",
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))


if __name__ == "__main__":
    unittest.main()



import time
import uuid
from typing import List, Optional

from openai.types.beta.thread import Thread
from openai.types.beta.threads.message import Message, MessageContent
from openai.types.beta.threads.run import Run
from openai.types.beta.threads.text import Text
from openai.types.beta.threads.text_content_block import TextContentBlock

from timestep.database import InstanceStoreSingleton


# def get_run(thread_id, run_id):  # noqa: E501
async def get_run(run_id, thread_id, token_info, user):
    """Retrieves a run.

     # noqa: E501

    :param thread_id: The ID of the [thread](/docs/api-reference/threads) that was run.
    :type thread_id: str
    :param run_id: The ID of the run to retrieve.
    :type run_id: str

    :rtype: Union[RunObject, Tuple[RunObject, int], Tuple[RunObject, int, Dict[str, str]]
    """
    print("=== get_run ===")

    # return InstanceStoreSingleton()._shared_instance_state["runs"].get(run_id).model_dump(mode="json")
    return InstanceStoreSingleton()._shared_instance_state["runs"].get(run_id)


# def modify_run(thread_id, run_id, modify_run_request):  # noqa: E501
async def modify_run(modify_run_request, run_id, token_info, thread_id, user, **kwargs):
    """Modifies a run.

     # noqa: E501

    :param thread_id: The ID of the [thread](/docs/api-reference/threads) that was run.
    :type thread_id: str
    :param run_id: The ID of the run to modify.
    :type run_id: str
    :param modify_run_request:
    :type modify_run_request: dict | bytes

    :rtype: Union[RunObject, Tuple[RunObject, int], Tuple[RunObject, int, Dict[str, str]]
    """
    # if connexion.request.is_json:
    #     modify_run_request = ModifyRunRequest.from_dict(connexion.request.get_json())  # noqa: E501

    print("=== modify_run ===")
    print("modify_run_request: ", modify_run_request)
    # print('args: ', args)
    print("kwargs: ", kwargs)

    run: Run = Run(
        **await get_run(
            run_id=run_id, token_info=token_info, thread_id=thread_id, user=user
        )
    )

    run.status = modify_run_request.get("status")

    InstanceStoreSingleton()._shared_instance_state["runs"][run_id] = run

    # return run.model_dump(mode="json")
    return run



import unittest

from flask import json

from timestep.api.openai.v1.models.delete_model_response import (  # noqa: E501
    DeleteModelResponse,
)
from timestep.api.openai.v1.models.list_models_response import (  # noqa: E501
    ListModelsResponse,
)
from timestep.api.openai.v1.models.model import Model  # noqa: E501
from timestep.api.openai.v1.test import BaseTestCase


class TestModelsController(BaseTestCase):
    """ModelsController integration test stubs"""

    def test_delete_model(self):
        """Test case for delete_model

        Delete a fine-tuned model. You must have the Owner role in your organization to delete a model.
        """
        headers = {
            "Accept": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/models/{model}".format(model="ft:gpt-3.5-turbo:acemeco:suffix:abc123"),
            method="DELETE",
            headers=headers,
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_list_models(self):
        """Test case for list_models

        Lists the currently available models, and provides basic information about each one such as the owner and availability.
        """
        headers = {
            "Accept": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open("/v1/models", method="GET", headers=headers)
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_retrieve_model(self):
        """Test case for retrieve_model

        Retrieves a model instance, providing basic information about the model such as the owner and permissioning.
        """
        headers = {
            "Accept": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/models/{model}".format(model="gpt-3.5-turbo"),
            method="GET",
            headers=headers,
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))


if __name__ == "__main__":
    unittest.main()



import unittest

from flask import json

from timestep.api.openai.v1.models.create_fine_tuning_job_request import (  # noqa: E501
    CreateFineTuningJobRequest,
)
from timestep.api.openai.v1.models.fine_tuning_job import FineTuningJob  # noqa: E501
from timestep.api.openai.v1.models.list_fine_tuning_job_checkpoints_response import (  # noqa: E501
    ListFineTuningJobCheckpointsResponse,
)
from timestep.api.openai.v1.models.list_fine_tuning_job_events_response import (  # noqa: E501
    ListFineTuningJobEventsResponse,
)
from timestep.api.openai.v1.models.list_paginated_fine_tuning_jobs_response import (  # noqa: E501
    ListPaginatedFineTuningJobsResponse,
)
from timestep.api.openai.v1.test import BaseTestCase


class TestFineTuningController(BaseTestCase):
    """FineTuningController integration test stubs"""

    def test_cancel_fine_tuning_job(self):
        """Test case for cancel_fine_tuning_job

        Immediately cancel a fine-tune job.
        """
        headers = {
            "Accept": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/fine_tuning/jobs/{fine_tuning_job_id}/cancel".format(
                fine_tuning_job_id="ft-AF1WoRqd3aJAHsqc9NY7iL8F"
            ),
            method="POST",
            headers=headers,
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_create_fine_tuning_job(self):
        """Test case for create_fine_tuning_job

        Creates a fine-tuning job which begins the process of creating a new model from a given dataset.  Response includes details of the enqueued job including job status and the name of the fine-tuned models once complete.  [Learn more about fine-tuning](/docs/guides/fine-tuning)
        """
        create_fine_tuning_job_request = {
            "training_file": "file-abc123",
            "seed": 42,
            "validation_file": "file-abc123",
            "hyperparameters": {
                "batch_size": "auto",
                "n_epochs": "auto",
                "learning_rate_multiplier": "auto",
            },
            "model": "gpt-3.5-turbo",
            "suffix": "suffix",
            "integrations": [
                {
                    "wandb": {
                        "name": "name",
                        "project": "my-wandb-project",
                        "entity": "entity",
                        "tags": ["custom-tag", "custom-tag"],
                    },
                    "type": "wandb",
                },
                {
                    "wandb": {
                        "name": "name",
                        "project": "my-wandb-project",
                        "entity": "entity",
                        "tags": ["custom-tag", "custom-tag"],
                    },
                    "type": "wandb",
                },
            ],
        }
        headers = {
            "Accept": "application/json",
            "Content-Type": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/fine_tuning/jobs",
            method="POST",
            headers=headers,
            data=json.dumps(create_fine_tuning_job_request),
            content_type="application/json",
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_list_fine_tuning_events(self):
        """Test case for list_fine_tuning_events

        Get status updates for a fine-tuning job.
        """
        query_string = [("after", "after_example"), ("limit", 20)]
        headers = {
            "Accept": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/fine_tuning/jobs/{fine_tuning_job_id}/events".format(
                fine_tuning_job_id="ft-AF1WoRqd3aJAHsqc9NY7iL8F"
            ),
            method="GET",
            headers=headers,
            query_string=query_string,
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_list_fine_tuning_job_checkpoints(self):
        """Test case for list_fine_tuning_job_checkpoints

        List checkpoints for a fine-tuning job.
        """
        query_string = [("after", "after_example"), ("limit", 10)]
        headers = {
            "Accept": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/fine_tuning/jobs/{fine_tuning_job_id}/checkpoints".format(
                fine_tuning_job_id="ft-AF1WoRqd3aJAHsqc9NY7iL8F"
            ),
            method="GET",
            headers=headers,
            query_string=query_string,
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_list_paginated_fine_tuning_jobs(self):
        """Test case for list_paginated_fine_tuning_jobs

        List your organization's fine-tuning jobs
        """
        query_string = [("after", "after_example"), ("limit", 20)]
        headers = {
            "Accept": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/fine_tuning/jobs",
            method="GET",
            headers=headers,
            query_string=query_string,
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_retrieve_fine_tuning_job(self):
        """Test case for retrieve_fine_tuning_job

        Get info about a fine-tuning job.  [Learn more about fine-tuning](/docs/guides/fine-tuning)
        """
        headers = {
            "Accept": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/fine_tuning/jobs/{fine_tuning_job_id}".format(
                fine_tuning_job_id="ft-AF1WoRqd3aJAHsqc9NY7iL8F"
            ),
            method="GET",
            headers=headers,
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))


if __name__ == "__main__":
    unittest.main()



import unittest

from flask import json

from timestep.api.openai.v1.test import BaseTestCase


class TestImagesController(BaseTestCase):
    """ImagesController integration test stubs"""

    def test_create_image(self):
        """Test case for create_image

        Creates an image given a prompt.
        """
        create_image_request = {
            "response_format": "url",
            "size": "1024x1024",
            "model": "dall-e-3",
            "style": "vivid",
            "prompt": "A cute baby sea otter",
            "user": "user-1234",
            "n": 1,
            "quality": "standard",
        }
        headers = {
            "Accept": "application/json",
            "Content-Type": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/images/generations",
            method="POST",
            headers=headers,
            data=json.dumps(create_image_request),
            content_type="application/json",
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    @unittest.skip("multipart/form-data not supported by Connexion")
    def test_create_image_edit(self):
        """Test case for create_image_edit

        Creates an edited or extended image given an original image and a prompt.
        """
        headers = {
            "Accept": "application/json",
            "Content-Type": "multipart/form-data",
            "Authorization": "Bearer special-key",
        }
        data = dict(
            image="/path/to/file",
            prompt="prompt_example",
            mask="/path/to/file",
            # model=timestep.api.openai.v1.CreateImageEditRequestModel(),
            n=1,
            # size=1024x1024,
            response_format=url,
            user="user_example",
        )
        response = self.client.open(
            "/v1/images/edits",
            method="POST",
            headers=headers,
            data=data,
            content_type="multipart/form-data",
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    @unittest.skip("multipart/form-data not supported by Connexion")
    def test_create_image_variation(self):
        """Test case for create_image_variation

        Creates a variation of a given image.
        """
        headers = {
            "Accept": "application/json",
            "Content-Type": "multipart/form-data",
            "Authorization": "Bearer special-key",
        }
        data = dict(
            image="/path/to/file",
            # model=timestep.api.openai.v1.CreateImageEditRequestModel(),
            n=1,
            # response_format=url,
            # size=1024x1024,
            user="user_example",
        )
        response = self.client.open(
            "/v1/images/variations",
            method="POST",
            headers=headers,
            data=data,
            content_type="multipart/form-data",
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))


if __name__ == "__main__":
    unittest.main()



from datetime import date, datetime  # noqa: F401
from typing import Dict, List  # noqa: F401

from timestep.api.ap.v1 import util
from timestep.api.ap.v1.models.base_model import Model
from timestep.api.ap.v1.models.pagination import Pagination  # noqa: E501
from timestep.api.ap.v1.models.task import Task  # noqa: E501


class TaskListResponse(Model):
    """NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).

    Do not edit the class manually.
    """

    def __init__(self, tasks=None, pagination=None):  # noqa: E501
        """TaskListResponse - a model defined in OpenAPI

        :param tasks: The tasks of this TaskListResponse.  # noqa: E501
        :type tasks: List[Task]
        :param pagination: The pagination of this TaskListResponse.  # noqa: E501
        :type pagination: Pagination
        """
        self.openapi_types = {"tasks": List[Task], "pagination": Pagination}

        self.attribute_map = {"tasks": "tasks", "pagination": "pagination"}

        self._tasks = tasks
        self._pagination = pagination

    @classmethod
    def from_dict(cls, dikt) -> "TaskListResponse":
        """Returns the dict as a model

        :param dikt: A dict.
        :type: dict
        :return: The TaskListResponse of this TaskListResponse.  # noqa: E501
        :rtype: TaskListResponse
        """
        return util.deserialize_model(dikt, cls)

    @property
    def tasks(self) -> List[Task]:
        """Gets the tasks of this TaskListResponse.


        :return: The tasks of this TaskListResponse.
        :rtype: List[Task]
        """
        return self._tasks

    @tasks.setter
    def tasks(self, tasks: List[Task]):
        """Sets the tasks of this TaskListResponse.


        :param tasks: The tasks of this TaskListResponse.
        :type tasks: List[Task]
        """
        if tasks is None:
            raise ValueError(
                "Invalid value for `tasks`, must not be `None`"
            )  # noqa: E501

        self._tasks = tasks

    @property
    def pagination(self) -> Pagination:
        """Gets the pagination of this TaskListResponse.


        :return: The pagination of this TaskListResponse.
        :rtype: Pagination
        """
        return self._pagination

    @pagination.setter
    def pagination(self, pagination: Pagination):
        """Sets the pagination of this TaskListResponse.


        :param pagination: The pagination of this TaskListResponse.
        :type pagination: Pagination
        """
        if pagination is None:
            raise ValueError(
                "Invalid value for `pagination`, must not be `None`"
            )  # noqa: E501

        self._pagination = pagination



import unittest

from flask import json

from timestep.api.openai.v1.models.create_completion_request import (  # noqa: E501
    CreateCompletionRequest,
)
from timestep.api.openai.v1.models.create_completion_response import (  # noqa: E501
    CreateCompletionResponse,
)
from timestep.api.openai.v1.test import BaseTestCase


class TestCompletionsController(BaseTestCase):
    """CompletionsController integration test stubs"""

    def test_create_completion(self):
        """Test case for create_completion

        Creates a completion for the provided prompt and parameters.
        """
        create_completion_request = {
            "logit_bias": {"key": 1},
            "seed": -2147483648,
            "max_tokens": 16,
            "presence_penalty": 0.25495066265333133,
            "echo": False,
            "suffix": "test.",
            "n": 1,
            "logprobs": 2,
            "top_p": 1,
            "frequency_penalty": 0.4109824732281613,
            "best_of": 1,
            "stop": "\n",
            "stream": False,
            "temperature": 1,
            "model": "CreateCompletionRequest_model",
            "stream_options": {"include_usage": True},
            "prompt": "This is a test.",
            "user": "user-1234",
        }
        headers = {
            "Accept": "application/json",
            "Content-Type": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/completions",
            method="POST",
            headers=headers,
            data=json.dumps(create_completion_request),
            content_type="application/json",
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))


if __name__ == "__main__":
    unittest.main()



import time
import uuid

import typer
from llama_cpp import Llama
from llama_cpp.llama_chat_format import (
    Llama3VisionAlpha,
    Llava15ChatHandler,
    Llava16ChatHandler,
    MoondreamChatHandler,
    NanoLlavaChatHandler,
)
from llama_cpp.llama_tokenizer import LlamaHFTokenizer
from openai.types.model import Model
from sqlmodel import Field, SQLModel
from stable_diffusion_cpp import StableDiffusion

app_dir = typer.get_app_dir("timestep")
# from timestep.database import InstanceStoreSingleton


async def get_default_agent():
    return None


# class AgentService(object):
#     # models: dict[uuid.UUID] = {}
#     _shared_instance_state = {
#         "models": {},
#     }

#     def __new__(cls, *args, **kwargs):
#         obj = super(AgentService, cls).__new__(cls, *args, **kwargs)
#         obj.__dict__ = cls._shared_instance_state

#         return obj


class ModelSQLModel(Model, SQLModel, table=True):
    __tablename__: str = "models"
    # object: str = "model"
    id: uuid.UUID = Field(default_factory=uuid.uuid4, primary_key=True)
    # id: uuid.uuid4 = Field(default_factory=uuid.uuid4, primary_key=True)

    # group_id: uuid.UUID = Field(foreign_key=groups.id)
    object: str = "model"
    # organization_id: uuid.UUID = Field(foreign_key=organizations.id)


class ModelInstanceStoreSingleton(object):
    _shared_model_instances: dict[str] = {}

    def __new__(cls, *args, **kwargs):
        obj = super(ModelInstanceStoreSingleton, cls).__new__(cls, *args, **kwargs)
        obj.__dict__ = cls._shared_model_instances

        return obj

    def create_model(self, model_aliases=[], model_name=None):
        # chat_format = None
        chat_format = "chatml-function-calling"
        chat_handler = None
        echo = True
        embedding = False
        filename = None
        mmproj_model_filename = "*mmproj*"
        mmproj_model_repo_id = None
        model_instance = None
        # n_ctx = 2048
        n_ctx = 4096
        # n_ctx = 8192
        # n_ctx = 16192
        n_gpu_layers = -1
        num_pred_tokens = (
            2 if n_gpu_layers == 0 else 10
        )  # num_pred_tokens is the number of tokens to predict 10 is the default and generally good for gpu, 2 performs better for cpu-only machines.
        text_model_filename = "*text-model*"
        text_model_repo_id = None
        tokenizer = None
        verbose = True

        if model_name == "BakLLaVA-1":
            mmproj_model_filename = "mmproj-model-f16.gguf"
            mmproj_model_repo_id = "mys/ggml_bakllava-1"
            text_model_filename = "ggml-model-q4_k.gguf"
            text_model_repo_id = mmproj_model_repo_id

            chat_handler = Llava15ChatHandler.from_pretrained(
                repo_id=mmproj_model_repo_id,
                filename=mmproj_model_filename,
            )

        elif model_name == "Functionary-V2.5":
            chat_format = chat_format if chat_format else "functionary-v2"
            text_model_repo_id = "meetkai/functionary-small-v2.5-GGUF"
            text_model_filename = "functionary-small-v2.5.Q4_0.gguf"
            tokenizer = LlamaHFTokenizer.from_pretrained(text_model_repo_id)

        elif model_name == "Llama-3-Vision-Alpha":
            mmproj_model_repo_id = "abetlen/llama-3-vision-alpha-gguf"
            text_model_filename = "Meta-Llama-3-8B.Q4_K_M.gguf"
            text_model_repo_id = "QuantFactory/Meta-Llama-3-8B-GGUF"

            if chat_format is None:
                chat_handler = Llama3VisionAlpha.from_pretrained(
                    repo_id=mmproj_model_repo_id,
                    filename=mmproj_model_filename,
                )

        elif model_name == "LLaVA-NeXT-Vicuna-7B":
            mmproj_model_filename = "mmproj-vicuna7b-f16-q6_k.gguf"
            mmproj_model_repo_id = "cmp-nct/llava-1.6-gguf"
            text_model_filename = "vicuna-7b-q5_k.gguf"
            text_model_repo_id = mmproj_model_repo_id

            if chat_format is None:
                chat_handler = Llava16ChatHandler.from_pretrained(
                    repo_id=mmproj_model_repo_id,
                    filename=mmproj_model_filename,
                )

        elif model_name == "LLaVA-Phi-3-Mini":
            mmproj_model_filename = "llava-phi-3-mini-int4.gguf"
            mmproj_model_repo_id = "xtuner/llava-phi-3-mini-gguf"
            text_model_filename = "llava-phi-3-mini-mmproj-f16.gguf"
            text_model_repo_id = mmproj_model_repo_id

        elif model_name == "MobileVLM-1.7B":
            mmproj_model_filename = "MobileVLM-1.7B-mmproj-f16.gguf"
            mmproj_model_repo_id = "guinmoon/MobileVLM-1.7B-GGUF"
            text_model_filename = "MobileVLM-1.7B-Q4_K.gguf"
            text_model_repo_id = mmproj_model_repo_id

        elif model_name == "MobileVLM_V2-1.7B":
            mmproj_model_filename = "mmproj-model-f16.gguf"
            mmproj_model_repo_id = "ZiangWu/MobileVLM_V2-1.7B-GGUF"
            text_model_filename = "ggml-model-q4_k.gguf"
            text_model_repo_id = mmproj_model_repo_id

        elif model_name == "moondream2":
            mmproj_model_repo_id = "vikhyatk/moondream2"
            text_model_repo_id = mmproj_model_repo_id

            if chat_format is None:
                chat_handler = MoondreamChatHandler.from_pretrained(
                    repo_id=mmproj_model_repo_id,
                    filename=mmproj_model_filename,
                )

        elif model_name == "nanoLLaVA":
            mmproj_model_repo_id = "abetlen/nanollava-gguf"
            text_model_repo_id = mmproj_model_repo_id

            if chat_format is None:
                chat_handler = NanoLlavaChatHandler.from_pretrained(
                    repo_id=mmproj_model_repo_id,
                    filename=mmproj_model_filename,
                )

        elif model_name == "OpenLLaMA-3Bv2":
            text_model_filename = "open_llama_3b_v2-q8_0.gguf"
            text_model_repo_id = "mjschock/open_llama_3b_v2-Q8_0-GGUF"

        elif model_name == "Phi-3-Mini-4K-Instruct":
            text_model_filename = "Phi-3-mini-4k-instruct-q4.gguf"
            text_model_repo_id = "microsoft/Phi-3-mini-4k-instruct-gguf"
            tokenizer = LlamaHFTokenizer.from_pretrained(
                "microsoft/Phi-3-mini-4k-instruct"
            )

        elif model_name == "Replit-Code-V-1.5-3B":
            n_ctx = 16192
            text_model_filename = "replit-code-v1_5-3b.Q4_0.gguf"
            text_model_repo_id = "abetlen/replit-code-v1_5-3b-GGUF"

        elif model_name == "SmolLM-135M":
            text_model_filename = "SmolLM-135M-F16.gguf"
            text_model_repo_id = "stillerman/SmolLM-135M-Llamafile"

        elif model_name == "Stable-Diffusion-v1-5":
            model_instance = StableDiffusion(
                model_path=f"{app_dir}/models/runwayml/stable-diffusion-v1-5/v1-5-pruned-emaonly.safetensors",
                wtype="default",  # Weight type (options: default, f32, f16, q4_0, q4_1, q5_0, q5_1, q8_0)
                # seed=1337, # Uncomment to set a specific seed
            )

        elif model_name == "TinyLlama-1.1B":
            text_model_filename = "tinyllama-1.1b-chat-v1.0.Q4_K_M.gguf"
            text_model_repo_id = "TheBloke/TinyLlama-1.1B-Chat-v1.0-GGUF"

        elif model_name == "TinySolar-248m-4k-py":
            text_model_filename = "tinysolar-248m-4k-py-q4_k_m.gguf"
            text_model_repo_id = "mjschock/TinySolar-248m-4k-py-Q4_K_M-GGUF"

        else:
            raise NotImplementedError(model_name)

        model_id = str(uuid.uuid4)  # TODO: insert model in db and get id

        # model = Llama( # TODO: switch to LangChain LL?
        model_instance = model_instance or Llama.from_pretrained(
            chat_format=chat_format,
            chat_handler=chat_handler,
            echo=echo,
            # draft_model=LlamaPromptLookupDecoding(num_pred_tokens=num_pred_tokens),
            embedding=embedding,
            filename=text_model_filename,
            model_alias=model_id,
            n_ctx=n_ctx,
            n_gpu_layers=n_gpu_layers,
            repo_id=text_model_repo_id,
            tokenizer=tokenizer,
            verbose=verbose,
        )

        for model_id in [model_id] + model_aliases + [model_name]:
            self._shared_model_instances[model_id] = model_instance

    def delete_model(self, model):  # noqa: E501
        """Delete a fine-tuned model. You must have the Owner role in your organization to delete a model.

        # noqa: E501

        :param model: The model to delete
        :type model: str

        :rtype: Union[DeleteModelResponse, Tuple[DeleteModelResponse, int], Tuple[DeleteModelResponse, int, Dict[str, str]]
        """
        raise NotImplementedError

    def list_models(self):  # noqa: E501
        """Lists the currently available models, and provides basic information about each one such as the owner and availability.

        # noqa: E501


        :rtype: Union[ListModelsResponse, Tuple[ListModelsResponse, int], Tuple[ListModelsResponse, int, Dict[str, str]]
        """
        raise NotImplementedError

    def retrieve_model(self, model_id: str):
        """Retrieves a model instance, providing basic information about the model such as the owner and permissioning.

        # noqa: E501

        :param model: The ID of the model to use for this request
        :type model: str

        :rtype: Union[Model, Tuple[Model, int], Tuple[Model, int, Dict[str, str]]
        """

        model: Llama = model_instance_store._shared_instance_state["models"][model_id]

        return {
            "chat_format": model.chat_format,
            "model_path": model.model_path,
            "n_ctx": model.n_ctx(),
            "lora_base": model.lora_base,
            "lora_path": model.lora_path,
            "lora_scale": model.lora_scale,
        }


model_instance_store = ModelInstanceStoreSingleton()
model_instance_store.created_at = time.time()

model_instance_store.create_model(
    model_aliases=[
        "gpt-3.5-turbo",
        "gpt-3.5-turbo-1106",
        "gpt-4-1106-preview",
        "gpt-4-turbo",
        "gpt-4o",
        "gpt-4o-mini",
        "LLaMA_CPP",
    ],
    # model_name="SmolLM-135M",
    model_name="TinySolar-248m-4k-py",
)

# model_instance_store.create_model(
#     model_aliases=[
#         "dall-e-2",
#         "dall-e-3",
#     ],
#     model_name="Stable-Diffusion-v1-5",
# )

# model_instance_store.create_model(
#     model_aliases=[
#         "text-embedding-3-small",
#         "text-embedding-3-large",
#         "text-embedding-ada-002",
#     ],
# )

# model_instance_store.create_model(
#     model_aliases=[
#         "tts-1",
#         "tts-1-hd",
#     ],
# )

# model_instance_store.create_model(
#     model_aliases=[
#         "whisper-1",
#     ],
# )



from typing import Dict, Tuple, Union

import connexion

from timestep.api.openai.v1 import util
from timestep.api.openai.v1.models.create_embedding_request import (  # noqa: E501
    CreateEmbeddingRequest,
)
from timestep.api.openai.v1.models.create_embedding_response import (  # noqa: E501
    CreateEmbeddingResponse,
)


def create_embedding(create_embedding_request):  # noqa: E501
    """Creates an embedding vector representing the input text.

     # noqa: E501

    :param create_embedding_request:
    :type create_embedding_request: dict | bytes

    :rtype: Union[CreateEmbeddingResponse, Tuple[CreateEmbeddingResponse, int], Tuple[CreateEmbeddingResponse, int, Dict[str, str]]
    """
    if connexion.request.is_json:
        create_embedding_request = CreateEmbeddingRequest.from_dict(
            connexion.request.get_json()
        )  # noqa: E501
    raise NotImplementedError



import asyncio
import datetime
import json
import pprint
import time
from typing import Iterator

from langchain.chains.base import Chain

# from langchain_community.llms import LlamaCpp
from langchain_community.llms.llamacpp import LlamaCpp
from langchain_core.callbacks import CallbackManager, StreamingStdOutCallbackHandler
from langchain_core.messages import HumanMessage
from langchain_core.output_parsers import (
    PydanticOutputParser,
    PydanticToolsParser,
    StrOutputParser,
)
from langchain_core.prompt_values import ChatPromptValue, PromptValue, StringPromptValue
from langchain_core.prompts import (
    ChatPromptTemplate,
    MessagesPlaceholder,
    PromptTemplate,
)
from llama_cpp import CreateChatCompletionStreamResponse, Llama
from llama_cpp.server.types import CreateChatCompletionRequest
from openai.types.chat.chat_completion import ChatCompletion
from openai.types.chat.chat_completion_chunk import ChatCompletionChunk
from openai.types.chat.completion_create_params import (
    CompletionCreateParams,
    CompletionCreateParamsNonStreaming,
    CompletionCreateParamsStreaming,
)
from sse_starlette import EventSourceResponse

from timestep.services.agent_service import ModelInstanceStoreSingleton

model_instance_store = ModelInstanceStoreSingleton()


async def create_chat_completion(
    body: CompletionCreateParams, token_info: dict, user: str
):
    """Creates a model response for the given chat conversation.

     # noqa: E501

    :param create_chat_completion_request:
    :type create_chat_completion_request: dict | bytes

    :rtype: Union[CreateChatCompletionResponse, Tuple[CreateChatCompletionResponse, int], Tuple[CreateChatCompletionResponse, int, Dict[str, str]]
    """
    # if connexion.request.is_json:
    # create_chat_completion_request = CreateChatCompletionRequest.from_dict(connexion.request.get_json())  # noqa: E501
    print(
        f"=== ENTER: {__name__}.create_chat_completion(body: CompletionCreateParams, token_info: dict, user: str)) ==="
    )
    pprint.pp(
        {
            "body": body,
            "token_info": token_info,
            "user": user,
        },
        compact=True,
        width=160,
    )

    # completion_create_params = CompletionCreateParams(**body)
    # print('completion_create_params:', completion_create_params)

    # if body.get("stream", False):
    #     completion_create_params = CompletionCreateParamsStreaming(**body)

    # else:
    #     completion_create_params = CompletionCreateParamsNonStreaming(**body)

    # TODO: does LangChain's LLamaCpp support mmproj models? Also, what's the best practice for converting response to OpenAI's ChatCompletion?
    # chat_prompt_template = ChatPromptTemplate.from_messages([
    #     ("system", "You are a helpful assistant"), # TODO: message history from user
    #     MessagesPlaceholder("msgs")
    # ])

    # # Callbacks support token-wise streaming
    # callback_manager = CallbackManager([StreamingStdOutCallbackHandler()])

    # llm_kwargs = {
    #     # "chat_format": "nanollava",
    #     # "clip_model_path": "nanollava-mmproj-f16.gguf",
    #     # "embedding": False,
    #     # "hf_model_repo_id": "abetlen/nanollava-gguf",
    #     # "model": "nanollava-text-model-f16.gguf",
    #     # "model_alias": "nanoLLaVA",
    #     # "model_path": "models/mofosyne/TinyLLama-v0-5M-F16-llamafile/Tinyllama-5M-v0.2-F16.gguf",
    #     "n_ctx": 2048,
    #     "verbose": True,
    # }

    # # Make sure the model path is correct for your system!
    # model = LlamaCpp(
    #     callback_manager=callback_manager,
    #     grammar_path="timestep/grammers/json.gbnf",
    #     # model_path="models/mofosyne/TinyLLama-v0-5M-F16-llamafile/Tinyllama-5M-v0.2-F16.gguf",
    #     model_path="models/abetlen/nanollava-gguf/nanollava-text-model-f16.gguf",
    #     streaming=True, # default is True...
    #     # temperature=0.0,
    #     # # max_tokens=2048,
    #     # # top_p=1,
    #     # callback_manager=callback_manager,
    #     # verbose=True,  # Verbose is required to pass to the callback manager
    #     **llm_kwargs,
    # )

    # chain: Chain = chat_prompt_template | model

    # if completion_create_params.get("stream", False):
    #     async for event in chain.astream_events({"msgs": completion_create_params.get("messages")}, version="v2"):
    #         kind = event["event"]

    #         if kind == "on_chat_model_stream":
    #             print(event, end="|", flush=True)

    #         raise NotImplementedError("Streaming is not supported yet")

    # else:
    #     result = await chain.ainvoke({"msgs": completion_create_params.get("messages")})
    #     print('result:', result)

    # return result

    create_chat_completion_request = CreateChatCompletionRequest(**body)
    create_chat_completion_kwargs = create_chat_completion_request.model_dump(
        exclude=[
            "logit_bias_type",
            "min_tokens",
            "n",
            "user",
        ]
    )
    # messages = create_chat_completion_request.messages

    # instance_store = InstanceStoreSingleton()
    model: Llama = model_instance_store._shared_model_instances[
        create_chat_completion_request.model
    ]

    if create_chat_completion_request.stream:

        async def event_publisher():
            response: Iterator[CreateChatCompletionStreamResponse] = (
                model.create_chat_completion(**create_chat_completion_kwargs)
            )
            # response: Generator[ChatCompletionChunk] = model.create_chat_completion_openai_v1(**create_chat_completion_kwargs)
            # response: Stream[ChatCompletionChunk] = model.astream(input=messages)

            try:
                for chunk in response:
                    # async for chunk in response:
                    chunk = ChatCompletionChunk(**chunk)
                    # yield json.dumps(chunk)
                    yield json.dumps(chunk.model_dump(mode="json"))
                    # yield ChatCompletionChunk(**chunk).model_dump(mode="json")
                    # yield chunk.model_dump(mode="json")

            except asyncio.CancelledError as e:
                # print(f"Disconnected from client (via refresh/close) {req.client}")
                print(f"Disconnected from client (via refresh/close)")
                # Do any other cleanup, if any
                raise e

        # print(f'=== RETURN: {__name__}.create_chat_completion(body: CompletionCreateParams, token_info: dict, user: str)) ===')
        return EventSourceResponse(event_publisher())

    else:
        # response: CreateChatCompletionResponse = model.create_chat_completion(**create_chat_completion_kwargs)
        response: ChatCompletion = model.create_chat_completion_openai_v1(
            **create_chat_completion_kwargs
        )

        # print(f'=== RETURN: {__name__}.create_chat_completion(body: CompletionCreateParams, token_info: dict, user: str)) ===')
        return response.model_dump(mode="json")



from typing import Optional

from pydantic import Field, SecretStr
from pydantic_settings import BaseSettings


class Settings(BaseSettings):
    # openai_api_key: SecretStr = Field(default=None)
    # poetry_pypi_token_testpypi: SecretStr = Field(default=None)
    # poetry_virtualenvs_create: bool = Field()
    # poetry_virtualenvs_in_project: bool = Field()
    # prefect_api_key: Optional[SecretStr] = Field(default=None)
    # prefect_api_url: str = Field(
    #     default="http://prefect-server.default.svc.cluster.local:4200/api"
    # )
    # pyenv_version: str = Field()
    # version: str = Field()

    class Config:
        env_file = ".env"
        env_file_encoding = "utf-8"
        secrets_dir = "./secrets"



from datetime import date, datetime  # noqa: F401
from typing import Dict, List  # noqa: F401

from timestep.api.ap.v1 import util
from timestep.api.ap.v1.models.base_model import Model


class GetAgentTask404Response(Model):
    """NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).

    Do not edit the class manually.
    """

    def __init__(self, message=None):  # noqa: E501
        """GetAgentTask404Response - a model defined in OpenAPI

        :param message: The message of this GetAgentTask404Response.  # noqa: E501
        :type message: str
        """
        self.openapi_types = {"message": str}

        self.attribute_map = {"message": "message"}

        self._message = message

    @classmethod
    def from_dict(cls, dikt) -> "GetAgentTask404Response":
        """Returns the dict as a model

        :param dikt: A dict.
        :type: dict
        :return: The getAgentTask_404_response of this GetAgentTask404Response.  # noqa: E501
        :rtype: GetAgentTask404Response
        """
        return util.deserialize_model(dikt, cls)

    @property
    def message(self) -> str:
        """Gets the message of this GetAgentTask404Response.

        Message stating the entity was not found  # noqa: E501

        :return: The message of this GetAgentTask404Response.
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message: str):
        """Sets the message of this GetAgentTask404Response.

        Message stating the entity was not found  # noqa: E501

        :param message: The message of this GetAgentTask404Response.
        :type message: str
        """
        if message is None:
            raise ValueError(
                "Invalid value for `message`, must not be `None`"
            )  # noqa: E501

        self._message = message



import unittest

from flask import json

from timestep.api.openai.v1.models.delete_file_response import (  # noqa: E501
    DeleteFileResponse,
)
from timestep.api.openai.v1.models.list_files_response import (  # noqa: E501
    ListFilesResponse,
)
from timestep.api.openai.v1.models.open_ai_file import OpenAIFile  # noqa: E501
from timestep.api.openai.v1.test import BaseTestCase


class TestFilesController(BaseTestCase):
    """FilesController integration test stubs"""

    @unittest.skip("multipart/form-data not supported by Connexion")
    def test_create_file(self):
        """Test case for create_file

        Upload a file that can be used across various endpoints. Individual files can be up to 512 MB, and the size of all files uploaded by one organization can be up to 100 GB.  The Assistants API supports files up to 2 million tokens and of specific file types. See the [Assistants Tools guide](/docs/assistants/tools) for details.  The Fine-tuning API only supports `.jsonl` files. The input also has certain required formats for fine-tuning [chat](/docs/api-reference/fine-tuning/chat-input) or [completions](/docs/api-reference/fine-tuning/completions-input) models.  The Batch API only supports `.jsonl` files up to 100 MB in size. The input also has a specific required [format](/docs/api-reference/batch/request-input).  Please [contact us](https://help.openai.com/) if you need to increase these storage limits.
        """
        headers = {
            "Accept": "application/json",
            "Content-Type": "multipart/form-data",
            "Authorization": "Bearer special-key",
        }
        data = dict(file="/path/to/file", purpose="purpose_example")
        response = self.client.open(
            "/v1/files",
            method="POST",
            headers=headers,
            data=data,
            content_type="multipart/form-data",
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_delete_file(self):
        """Test case for delete_file

        Delete a file.
        """
        headers = {
            "Accept": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/files/{file_id}".format(file_id="file_id_example"),
            method="DELETE",
            headers=headers,
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_download_file(self):
        """Test case for download_file

        Returns the contents of the specified file.
        """
        headers = {
            "Accept": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/files/{file_id}/content".format(file_id="file_id_example"),
            method="GET",
            headers=headers,
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_list_files(self):
        """Test case for list_files

        Returns a list of files that belong to the user's organization.
        """
        query_string = [("purpose", "purpose_example")]
        headers = {
            "Accept": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/files", method="GET", headers=headers, query_string=query_string
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_retrieve_file(self):
        """Test case for retrieve_file

        Returns information about a specific file.
        """
        headers = {
            "Accept": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/files/{file_id}".format(file_id="file_id_example"),
            method="GET",
            headers=headers,
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))


if __name__ == "__main__":
    unittest.main()



import unittest

from flask import json

from timestep.api.ap.v1.models.artifact import Artifact  # noqa: E501
from timestep.api.ap.v1.models.get_agent_task404_response import (  # noqa: E501
    GetAgentTask404Response,
)
from timestep.api.ap.v1.models.step import Step  # noqa: E501
from timestep.api.ap.v1.models.step_request_body import StepRequestBody  # noqa: E501
from timestep.api.ap.v1.models.task import Task  # noqa: E501
from timestep.api.ap.v1.models.task_artifacts_list_response import (  # noqa: E501
    TaskArtifactsListResponse,
)
from timestep.api.ap.v1.models.task_list_response import TaskListResponse  # noqa: E501
from timestep.api.ap.v1.models.task_request_body import TaskRequestBody  # noqa: E501
from timestep.api.ap.v1.models.task_steps_list_response import (  # noqa: E501
    TaskStepsListResponse,
)
from timestep.api.ap.v1.test import BaseTestCase


class TestAgentController(BaseTestCase):
    """AgentController integration test stubs"""

    def test_create_agent_task(self):
        """Test case for create_agent_task

        Creates a task for the agent.
        """
        task_request_body = {
            "input": "Write 'Washington' to the file 'output.txt'.",
            "additional_input": '{\n"debug": false,\n"mode": "benchmarks"\n}',
        }
        headers = {
            "Accept": "application/json",
            "Content-Type": "application/json",
        }
        response = self.client.open(
            "/ap/v1/agent/tasks",
            method="POST",
            headers=headers,
            data=json.dumps(task_request_body),
            content_type="application/json",
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_download_agent_task_artifact(self):
        """Test case for download_agent_task_artifact

        Download a specified artifact.
        """
        headers = {
            "Accept": "application/json",
        }
        response = self.client.open(
            "/ap/v1/agent/tasks/{task_id}/artifacts/{artifact_id}".format(
                task_id="50da533e-3904-4401-8a07-c49adf88b5eb",
                artifact_id="1e41533e-3904-4401-8a07-c49adf8893de",
            ),
            method="GET",
            headers=headers,
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_execute_agent_task_step(self):
        """Test case for execute_agent_task_step

        Execute a step in the specified agent task.
        """
        step_request_body = {
            "input": "Write the words you receive to the file 'output.txt'.",
            "additional_input": '{\n"file_to_refactor": "models.py"\n}',
        }
        headers = {
            "Accept": "application/json",
            "Content-Type": "application/json",
        }
        response = self.client.open(
            "/ap/v1/agent/tasks/{task_id}/steps".format(
                task_id="50da533e-3904-4401-8a07-c49adf88b5eb"
            ),
            method="POST",
            headers=headers,
            data=json.dumps(step_request_body),
            content_type="application/json",
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_get_agent_task(self):
        """Test case for get_agent_task

        Get details about a specified agent task.
        """
        headers = {
            "Accept": "application/json",
        }
        response = self.client.open(
            "/ap/v1/agent/tasks/{task_id}".format(
                task_id="1d5a533e-3904-4401-8a07-c49adf88b981"
            ),
            method="GET",
            headers=headers,
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_get_agent_task_step(self):
        """Test case for get_agent_task_step

        Get details about a specified task step.
        """
        headers = {
            "Accept": "application/json",
        }
        response = self.client.open(
            "/ap/v1/agent/tasks/{task_id}/steps/{step_id}".format(
                task_id="50da533e-3904-4401-8a07-c49adf88b5eb",
                step_id="28ca533e-3904-4401-8a07-c49adf8891c2",
            ),
            method="GET",
            headers=headers,
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_list_agent_task_artifacts(self):
        """Test case for list_agent_task_artifacts

        List all artifacts that have been created for the given task.
        """
        query_string = [("current_page", 1), ("page_size", 10)]
        headers = {
            "Accept": "application/json",
        }
        response = self.client.open(
            "/ap/v1/agent/tasks/{task_id}/artifacts".format(
                task_id="50da533e-3904-4401-8a07-c49adf88b5eb"
            ),
            method="GET",
            headers=headers,
            query_string=query_string,
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_list_agent_task_steps(self):
        """Test case for list_agent_task_steps

        List all steps for the specified task.
        """
        query_string = [("current_page", 1), ("page_size", 10)]
        headers = {
            "Accept": "application/json",
        }
        response = self.client.open(
            "/ap/v1/agent/tasks/{task_id}/steps".format(
                task_id="50da533e-3904-4401-8a07-c49adf88b5eb"
            ),
            method="GET",
            headers=headers,
            query_string=query_string,
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_list_agent_tasks(self):
        """Test case for list_agent_tasks

        List all tasks that have been created for the agent.
        """
        query_string = [("current_page", 1), ("page_size", 10)]
        headers = {
            "Accept": "application/json",
        }
        response = self.client.open(
            "/ap/v1/agent/tasks",
            method="GET",
            headers=headers,
            query_string=query_string,
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    @unittest.skip("multipart/form-data not supported by Connexion")
    def test_upload_agent_task_artifacts(self):
        """Test case for upload_agent_task_artifacts

        Upload an artifact for the specified task.
        """
        headers = {
            "Accept": "application/json",
            "Content-Type": "multipart/form-data",
        }
        data = dict(file="/path/to/file", relative_path="relative_path_example")
        response = self.client.open(
            "/ap/v1/agent/tasks/{task_id}/artifacts".format(
                task_id="50da533e-3904-4401-8a07-c49adf88b5eb"
            ),
            method="POST",
            headers=headers,
            data=data,
            content_type="multipart/form-data",
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))


if __name__ == "__main__":
    unittest.main()



import unittest

from flask import json

from timestep.api.openai.v1.models.create_embedding_request import (  # noqa: E501
    CreateEmbeddingRequest,
)
from timestep.api.openai.v1.models.create_embedding_response import (  # noqa: E501
    CreateEmbeddingResponse,
)
from timestep.api.openai.v1.test import BaseTestCase


class TestEmbeddingsController(BaseTestCase):
    """EmbeddingsController integration test stubs"""

    def test_create_embedding(self):
        """Test case for create_embedding

        Creates an embedding vector representing the input text.
        """
        create_embedding_request = {
            "input": "The quick brown fox jumped over the lazy dog",
            "encoding_format": "float",
            "model": "text-embedding-3-small",
            "user": "user-1234",
            "dimensions": 1,
        }
        headers = {
            "Accept": "application/json",
            "Content-Type": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/embeddings",
            method="POST",
            headers=headers,
            data=json.dumps(create_embedding_request),
            content_type="application/json",
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))


if __name__ == "__main__":
    unittest.main()



from datetime import date, datetime  # noqa: F401
from typing import Dict, List  # noqa: F401

from timestep.api.ap.v1 import util
from timestep.api.ap.v1.models.artifact import Artifact  # noqa: E501
from timestep.api.ap.v1.models.base_model import Model


class Step(Model):
    """NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).

    Do not edit the class manually.
    """

    def __init__(
        self,
        input=None,
        additional_input=None,
        task_id=None,
        step_id=None,
        name=None,
        status=None,
        output=None,
        additional_output=None,
        artifacts=[],
        is_last=False,
    ):  # noqa: E501
        """Step - a model defined in OpenAPI

        :param input: The input of this Step.  # noqa: E501
        :type input: str
        :param additional_input: The additional_input of this Step.  # noqa: E501
        :type additional_input: object
        :param task_id: The task_id of this Step.  # noqa: E501
        :type task_id: str
        :param step_id: The step_id of this Step.  # noqa: E501
        :type step_id: str
        :param name: The name of this Step.  # noqa: E501
        :type name: str
        :param status: The status of this Step.  # noqa: E501
        :type status: str
        :param output: The output of this Step.  # noqa: E501
        :type output: str
        :param additional_output: The additional_output of this Step.  # noqa: E501
        :type additional_output: object
        :param artifacts: The artifacts of this Step.  # noqa: E501
        :type artifacts: List[Artifact]
        :param is_last: The is_last of this Step.  # noqa: E501
        :type is_last: bool
        """
        self.openapi_types = {
            "input": str,
            "additional_input": object,
            "task_id": str,
            "step_id": str,
            "name": str,
            "status": str,
            "output": str,
            "additional_output": object,
            "artifacts": List[Artifact],
            "is_last": bool,
        }

        self.attribute_map = {
            "input": "input",
            "additional_input": "additional_input",
            "task_id": "task_id",
            "step_id": "step_id",
            "name": "name",
            "status": "status",
            "output": "output",
            "additional_output": "additional_output",
            "artifacts": "artifacts",
            "is_last": "is_last",
        }

        self._input = input
        self._additional_input = additional_input
        self._task_id = task_id
        self._step_id = step_id
        self._name = name
        self._status = status
        self._output = output
        self._additional_output = additional_output
        self._artifacts = artifacts
        self._is_last = is_last

    @classmethod
    def from_dict(cls, dikt) -> "Step":
        """Returns the dict as a model

        :param dikt: A dict.
        :type: dict
        :return: The Step of this Step.  # noqa: E501
        :rtype: Step
        """
        return util.deserialize_model(dikt, cls)

    @property
    def input(self) -> str:
        """Gets the input of this Step.

        Input prompt for the step.  # noqa: E501

        :return: The input of this Step.
        :rtype: str
        """
        return self._input

    @input.setter
    def input(self, input: str):
        """Sets the input of this Step.

        Input prompt for the step.  # noqa: E501

        :param input: The input of this Step.
        :type input: str
        """

        self._input = input

    @property
    def additional_input(self) -> object:
        """Gets the additional_input of this Step.

        Input parameters for the task step. Any value is allowed.  # noqa: E501

        :return: The additional_input of this Step.
        :rtype: object
        """
        return self._additional_input

    @additional_input.setter
    def additional_input(self, additional_input: object):
        """Sets the additional_input of this Step.

        Input parameters for the task step. Any value is allowed.  # noqa: E501

        :param additional_input: The additional_input of this Step.
        :type additional_input: object
        """

        self._additional_input = additional_input

    @property
    def task_id(self) -> str:
        """Gets the task_id of this Step.

        The ID of the task this step belongs to.  # noqa: E501

        :return: The task_id of this Step.
        :rtype: str
        """
        return self._task_id

    @task_id.setter
    def task_id(self, task_id: str):
        """Sets the task_id of this Step.

        The ID of the task this step belongs to.  # noqa: E501

        :param task_id: The task_id of this Step.
        :type task_id: str
        """
        if task_id is None:
            raise ValueError(
                "Invalid value for `task_id`, must not be `None`"
            )  # noqa: E501

        self._task_id = task_id

    @property
    def step_id(self) -> str:
        """Gets the step_id of this Step.

        The ID of the task step.  # noqa: E501

        :return: The step_id of this Step.
        :rtype: str
        """
        return self._step_id

    @step_id.setter
    def step_id(self, step_id: str):
        """Sets the step_id of this Step.

        The ID of the task step.  # noqa: E501

        :param step_id: The step_id of this Step.
        :type step_id: str
        """
        if step_id is None:
            raise ValueError(
                "Invalid value for `step_id`, must not be `None`"
            )  # noqa: E501

        self._step_id = step_id

    @property
    def name(self) -> str:
        """Gets the name of this Step.

        The name of the task step.  # noqa: E501

        :return: The name of this Step.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name: str):
        """Sets the name of this Step.

        The name of the task step.  # noqa: E501

        :param name: The name of this Step.
        :type name: str
        """

        self._name = name

    @property
    def status(self) -> str:
        """Gets the status of this Step.

        The status of the task step.  # noqa: E501

        :return: The status of this Step.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status: str):
        """Sets the status of this Step.

        The status of the task step.  # noqa: E501

        :param status: The status of this Step.
        :type status: str
        """
        allowed_values = ["created", "running", "completed"]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}".format(
                    status, allowed_values
                )
            )

        self._status = status

    @property
    def output(self) -> str:
        """Gets the output of this Step.

        Output of the task step.  # noqa: E501

        :return: The output of this Step.
        :rtype: str
        """
        return self._output

    @output.setter
    def output(self, output: str):
        """Sets the output of this Step.

        Output of the task step.  # noqa: E501

        :param output: The output of this Step.
        :type output: str
        """

        self._output = output

    @property
    def additional_output(self) -> object:
        """Gets the additional_output of this Step.

        Output that the task step has produced. Any value is allowed.  # noqa: E501

        :return: The additional_output of this Step.
        :rtype: object
        """
        return self._additional_output

    @additional_output.setter
    def additional_output(self, additional_output: object):
        """Sets the additional_output of this Step.

        Output that the task step has produced. Any value is allowed.  # noqa: E501

        :param additional_output: The additional_output of this Step.
        :type additional_output: object
        """

        self._additional_output = additional_output

    @property
    def artifacts(self) -> List[Artifact]:
        """Gets the artifacts of this Step.

        A list of artifacts that the step has produced.  # noqa: E501

        :return: The artifacts of this Step.
        :rtype: List[Artifact]
        """
        return self._artifacts

    @artifacts.setter
    def artifacts(self, artifacts: List[Artifact]):
        """Sets the artifacts of this Step.

        A list of artifacts that the step has produced.  # noqa: E501

        :param artifacts: The artifacts of this Step.
        :type artifacts: List[Artifact]
        """
        if artifacts is None:
            raise ValueError(
                "Invalid value for `artifacts`, must not be `None`"
            )  # noqa: E501

        self._artifacts = artifacts

    @property
    def is_last(self) -> bool:
        """Gets the is_last of this Step.

        Whether this is the last step in the task.  # noqa: E501

        :return: The is_last of this Step.
        :rtype: bool
        """
        return self._is_last

    @is_last.setter
    def is_last(self, is_last: bool):
        """Sets the is_last of this Step.

        Whether this is the last step in the task.  # noqa: E501

        :param is_last: The is_last of this Step.
        :type is_last: bool
        """
        if is_last is None:
            raise ValueError(
                "Invalid value for `is_last`, must not be `None`"
            )  # noqa: E501

        self._is_last = is_last



import logging

import connexion
from flask_testing import TestCase

from timestep.api.ap.v1.encoder import JSONEncoder


class BaseTestCase(TestCase):

    def create_app(self):
        logging.getLogger("connexion.operation").setLevel("ERROR")
        app = connexion.App(__name__, specification_dir="../openapi/")
        app.app.json_encoder = JSONEncoder
        app.add_api("openapi.yaml", pythonic_params=True)
        return app.app



import asyncio
import json
from typing import Iterator

from llama_cpp import Llama
from llama_cpp.llama_types import CreateCompletionStreamResponse
from llama_cpp.server.types import CreateCompletionRequest
from openai.types.completion import Completion
from sse_starlette import EventSourceResponse

from timestep.services import agent_service

model_instance_store = agent_service.ModelInstanceStoreSingleton()


# @flow(log_prints=True)
async def create_completion(body, token_info: dict, user: str):  # noqa: E501
    """Creates a completion for the provided prompt and parameters.

     # noqa: E501

    :param create_completion_request:
    :type create_completion_request: dict | bytes

    :rtype: Union[CreateCompletionResponse, Tuple[CreateCompletionResponse, int], Tuple[CreateCompletionResponse, int, Dict[str, str]]
    """
    # if connexion.request.is_json:
    #     create_completion_request = CreateCompletionRequest.from_dict(connexion.request.get_json())  # noqa: E501
    # raise NotImplementedError

    # print(f'=== ENTER: {__name__}.create_completion(body, token_info: dict, user: str) ===')
    # pprint.pp({
    #     "body": body,
    #     "token_info": token_info,
    #     "user": user,
    # })

    create_completion_request = CreateCompletionRequest(**body)
    create_completion_kwargs = create_completion_request.model_dump(
        exclude=[
            "best_of",
            "logit_bias",  # ValueError: invalid literal for int() with base 10: 'key' for { "key": 1 }
            "logit_bias_type",
            "logprobs",  # ValueError: logprobs is not supported for models created with logits_all=False
            "min_tokens",
            "n",
            "user",
        ]
    )
    # instance_store = InstanceStoreSingleton()
    # model: Llama = instance_store._shared_instance_state["models"][create_completion_request.model]
    # model: Llama = agent_service.get_default_agent().get_model(create_completion_request.model)
    model: Llama = model_instance_store._shared_model_instances[
        create_completion_request.model
    ]

    if create_completion_request.stream:

        async def event_publisher():
            response: Iterator[CreateCompletionStreamResponse] = (
                model.create_completion(**create_completion_kwargs)
            )

            try:
                for chunk in response:
                    # chunk = Completion(**chunk)
                    # chunk = Stream
                    yield json.dumps(chunk)
                    # yield json.dumps(chunk.model_dump(mode="json"))
                    # await asyncio.sleep(0.2)

            except asyncio.CancelledError as e:
                # print(f"Disconnected from client (via refresh/close) {req.client}")
                print(f"Disconnected from client (via refresh/close)")
                # Do any other cleanup, if any
                raise e

        # print(f'=== RETURN: {__name__}.create_completion(body, token_info: dict, user: str) ===')
        return EventSourceResponse(event_publisher())

    else:
        response: CreateCompletionStreamResponse = model.create_completion(
            **create_completion_kwargs
        )
        completion = Completion(**response)

        # print(f'=== RETURN: {__name__}.create_completion(body, token_info: dict, user: str) ===')
        return completion.model_dump(mode="json")



#!/usr/bin/env python3

import connexion

from timestep.api.openai.v1 import encoder


def main():
    app = connexion.App(__name__, specification_dir="./openapi/")
    app.app.json_encoder = encoder.JSONEncoder
    app.add_api("openapi.yaml", arguments={"title": "OpenAI API"}, pythonic_params=True)

    app.run(port=8080)


if __name__ == "__main__":
    main()



from typing import Dict, Tuple, Union

import connexion
from openai.types.model import Model

from timestep.api.openai.v1 import util
from timestep.api.openai.v1.models.delete_model_response import (  # noqa: E501
    DeleteModelResponse,
)
from timestep.api.openai.v1.models.list_models_response import (  # noqa: E501
    ListModelsResponse,
)
from timestep.api.openai.v1.models.model import Model  # noqa: E501
from timestep.services import model_service


def delete_model(model):  # noqa: E501
    """Delete a fine-tuned model. You must have the Owner role in your organization to delete a model.

     # noqa: E501

    :param model: The model to delete
    :type model: str

    :rtype: Union[DeleteModelResponse, Tuple[DeleteModelResponse, int], Tuple[DeleteModelResponse, int, Dict[str, str]]
    """
    raise NotImplementedError


def list_models():  # noqa: E501
    """Lists the currently available models, and provides basic information about each one such as the owner and availability.

     # noqa: E501


    :rtype: Union[ListModelsResponse, Tuple[ListModelsResponse, int], Tuple[ListModelsResponse, int, Dict[str, str]]
    """
    raise NotImplementedError


def retrieve_model(model: str, token_info: dict, user: str):
    """Retrieves a model instance, providing basic information about the model such as the owner and permissioning.

     # noqa: E501

    :param model: The ID of the model to use for this request
    :type model: str

    :rtype: Union[Model, Tuple[Model, int], Tuple[Model, int, Dict[str, str]]
    """
    # print('args: ', args)
    # print('kwargs: ', kwargs)

    model_info = model_service.retrieve_model(model_id=model)

    print("model_info: ", model_info)

    return Model(
        id=model,
        created=0,
        object="model",
        owned_by=user,
    ).model_dump(mode="json")



from typing import Dict, Tuple, Union

import connexion

from timestep.api.ap.v1 import util
from timestep.api.ap.v1.models.artifact import Artifact  # noqa: E501
from timestep.api.ap.v1.models.get_agent_task404_response import (  # noqa: E501
    GetAgentTask404Response,
)
from timestep.api.ap.v1.models.step import Step  # noqa: E501
from timestep.api.ap.v1.models.step_request_body import StepRequestBody  # noqa: E501
from timestep.api.ap.v1.models.task import Task  # noqa: E501
from timestep.api.ap.v1.models.task_artifacts_list_response import (  # noqa: E501
    TaskArtifactsListResponse,
)
from timestep.api.ap.v1.models.task_list_response import TaskListResponse  # noqa: E501
from timestep.api.ap.v1.models.task_request_body import TaskRequestBody  # noqa: E501
from timestep.api.ap.v1.models.task_steps_list_response import (  # noqa: E501
    TaskStepsListResponse,
)


def create_agent_task(task_request_body=None):  # noqa: E501
    """Creates a task for the agent.

     # noqa: E501

    :param task_request_body:
    :type task_request_body: dict | bytes

    :rtype: Union[Task, Tuple[Task, int], Tuple[Task, int, Dict[str, str]]
    """
    if connexion.request.is_json:
        task_request_body = TaskRequestBody.from_dict(
            connexion.request.get_json()
        )  # noqa: E501
    raise NotImplementedError


def download_agent_task_artifact(task_id, artifact_id):  # noqa: E501
    """Download a specified artifact.

     # noqa: E501

    :param task_id: ID of the task
    :type task_id: str
    :param artifact_id: ID of the artifact
    :type artifact_id: str

    :rtype: Union[file, Tuple[file, int], Tuple[file, int, Dict[str, str]]
    """
    raise NotImplementedError


def execute_agent_task_step(task_id, step_request_body=None):  # noqa: E501
    """Execute a step in the specified agent task.

     # noqa: E501

    :param task_id: ID of the task
    :type task_id: str
    :param step_request_body:
    :type step_request_body: dict | bytes

    :rtype: Union[Step, Tuple[Step, int], Tuple[Step, int, Dict[str, str]]
    """
    if connexion.request.is_json:
        step_request_body = StepRequestBody.from_dict(
            connexion.request.get_json()
        )  # noqa: E501
    raise NotImplementedError


def get_agent_task(task_id):  # noqa: E501
    """Get details about a specified agent task.

     # noqa: E501

    :param task_id: ID of the task
    :type task_id: str

    :rtype: Union[Task, Tuple[Task, int], Tuple[Task, int, Dict[str, str]]
    """
    raise NotImplementedError


def get_agent_task_step(task_id, step_id):  # noqa: E501
    """Get details about a specified task step.

     # noqa: E501

    :param task_id: ID of the task
    :type task_id: str
    :param step_id: ID of the step
    :type step_id: str

    :rtype: Union[Step, Tuple[Step, int], Tuple[Step, int, Dict[str, str]]
    """
    raise NotImplementedError


def list_agent_task_artifacts(task_id, current_page=None, page_size=None):  # noqa: E501
    """List all artifacts that have been created for the given task.

     # noqa: E501

    :param task_id: ID of the task
    :type task_id: str
    :param current_page: Page number
    :type current_page: int
    :param page_size: Number of items per page
    :type page_size: int

    :rtype: Union[TaskArtifactsListResponse, Tuple[TaskArtifactsListResponse, int], Tuple[TaskArtifactsListResponse, int, Dict[str, str]]
    """
    raise NotImplementedError


def list_agent_task_steps(task_id, current_page=None, page_size=None):  # noqa: E501
    """List all steps for the specified task.

     # noqa: E501

    :param task_id: ID of the task.
    :type task_id: str
    :param current_page: Page number
    :type current_page: int
    :param page_size: Number of items per page
    :type page_size: int

    :rtype: Union[TaskStepsListResponse, Tuple[TaskStepsListResponse, int], Tuple[TaskStepsListResponse, int, Dict[str, str]]
    """
    raise NotImplementedError


# def list_agent_tasks(current_page=None, page_size=None):  # noqa: E501
def list_agent_tasks(*args, **kwargs):
    """List all tasks that have been created for the agent.

     # noqa: E501

    :param current_page: Page number
    :type current_page: int
    :param page_size: Number of items per page
    :type page_size: int

    :rtype: Union[TaskListResponse, Tuple[TaskListResponse, int], Tuple[TaskListResponse, int, Dict[str, str]]
    """
    print(f"args: {args}")
    print(f"kwargs: {kwargs}")

    raise NotImplementedError


def upload_agent_task_artifacts(task_id, file, relative_path=None):  # noqa: E501
    """Upload an artifact for the specified task.

     # noqa: E501

    :param task_id: ID of the task
    :type task_id: str
    :param file: File to upload.
    :type file: str
    :param relative_path: Relative path of the artifact in the agent&#39;s workspace.
    :type relative_path: str

    :rtype: Union[Artifact, Tuple[Artifact, int], Tuple[Artifact, int, Dict[str, str]]
    """
    raise NotImplementedError



from datetime import date, datetime  # noqa: F401
from typing import Dict, List  # noqa: F401

from timestep.api.ap.v1 import util
from timestep.api.ap.v1.models.base_model import Model


class Artifact(Model):
    """NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).

    Do not edit the class manually.
    """

    def __init__(
        self, artifact_id=None, agent_created=None, file_name=None, relative_path=None
    ):  # noqa: E501
        """Artifact - a model defined in OpenAPI

        :param artifact_id: The artifact_id of this Artifact.  # noqa: E501
        :type artifact_id: str
        :param agent_created: The agent_created of this Artifact.  # noqa: E501
        :type agent_created: bool
        :param file_name: The file_name of this Artifact.  # noqa: E501
        :type file_name: str
        :param relative_path: The relative_path of this Artifact.  # noqa: E501
        :type relative_path: str
        """
        self.openapi_types = {
            "artifact_id": str,
            "agent_created": bool,
            "file_name": str,
            "relative_path": str,
        }

        self.attribute_map = {
            "artifact_id": "artifact_id",
            "agent_created": "agent_created",
            "file_name": "file_name",
            "relative_path": "relative_path",
        }

        self._artifact_id = artifact_id
        self._agent_created = agent_created
        self._file_name = file_name
        self._relative_path = relative_path

    @classmethod
    def from_dict(cls, dikt) -> "Artifact":
        """Returns the dict as a model

        :param dikt: A dict.
        :type: dict
        :return: The Artifact of this Artifact.  # noqa: E501
        :rtype: Artifact
        """
        return util.deserialize_model(dikt, cls)

    @property
    def artifact_id(self) -> str:
        """Gets the artifact_id of this Artifact.

        ID of the artifact.  # noqa: E501

        :return: The artifact_id of this Artifact.
        :rtype: str
        """
        return self._artifact_id

    @artifact_id.setter
    def artifact_id(self, artifact_id: str):
        """Sets the artifact_id of this Artifact.

        ID of the artifact.  # noqa: E501

        :param artifact_id: The artifact_id of this Artifact.
        :type artifact_id: str
        """
        if artifact_id is None:
            raise ValueError(
                "Invalid value for `artifact_id`, must not be `None`"
            )  # noqa: E501

        self._artifact_id = artifact_id

    @property
    def agent_created(self) -> bool:
        """Gets the agent_created of this Artifact.

        Whether the artifact has been created by the agent.  # noqa: E501

        :return: The agent_created of this Artifact.
        :rtype: bool
        """
        return self._agent_created

    @agent_created.setter
    def agent_created(self, agent_created: bool):
        """Sets the agent_created of this Artifact.

        Whether the artifact has been created by the agent.  # noqa: E501

        :param agent_created: The agent_created of this Artifact.
        :type agent_created: bool
        """
        if agent_created is None:
            raise ValueError(
                "Invalid value for `agent_created`, must not be `None`"
            )  # noqa: E501

        self._agent_created = agent_created

    @property
    def file_name(self) -> str:
        """Gets the file_name of this Artifact.

        Filename of the artifact.  # noqa: E501

        :return: The file_name of this Artifact.
        :rtype: str
        """
        return self._file_name

    @file_name.setter
    def file_name(self, file_name: str):
        """Sets the file_name of this Artifact.

        Filename of the artifact.  # noqa: E501

        :param file_name: The file_name of this Artifact.
        :type file_name: str
        """
        if file_name is None:
            raise ValueError(
                "Invalid value for `file_name`, must not be `None`"
            )  # noqa: E501

        self._file_name = file_name

    @property
    def relative_path(self) -> str:
        """Gets the relative_path of this Artifact.

        Relative path of the artifact in the agent's workspace.  # noqa: E501

        :return: The relative_path of this Artifact.
        :rtype: str
        """
        return self._relative_path

    @relative_path.setter
    def relative_path(self, relative_path: str):
        """Sets the relative_path of this Artifact.

        Relative path of the artifact in the agent's workspace.  # noqa: E501

        :param relative_path: The relative_path of this Artifact.
        :type relative_path: str
        """

        self._relative_path = relative_path



import unittest

from flask import json

from timestep.api.openai.v1.models.batch import Batch  # noqa: E501
from timestep.api.openai.v1.models.create_batch_request import (  # noqa: E501
    CreateBatchRequest,
)
from timestep.api.openai.v1.models.list_batches_response import (  # noqa: E501
    ListBatchesResponse,
)
from timestep.api.openai.v1.test import BaseTestCase


class TestBatchController(BaseTestCase):
    """BatchController integration test stubs"""

    def test_cancel_batch(self):
        """Test case for cancel_batch

        Cancels an in-progress batch. The batch will be in status `cancelling` for up to 10 minutes, before changing to `cancelled`, where it will have partial results (if any) available in the output file.
        """
        headers = {
            "Accept": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/batches/{batch_id}/cancel".format(batch_id="batch_id_example"),
            method="POST",
            headers=headers,
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_create_batch(self):
        """Test case for create_batch

        Creates and executes a batch from an uploaded file of requests
        """
        create_batch_request = timestep.api.openai.v1.CreateBatchRequest()
        headers = {
            "Accept": "application/json",
            "Content-Type": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/batches",
            method="POST",
            headers=headers,
            data=json.dumps(create_batch_request),
            content_type="application/json",
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_list_batches(self):
        """Test case for list_batches

        List your organization's batches.
        """
        query_string = [("after", "after_example"), ("limit", 20)]
        headers = {
            "Accept": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/batches", method="GET", headers=headers, query_string=query_string
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_retrieve_batch(self):
        """Test case for retrieve_batch

        Retrieves a batch.
        """
        headers = {
            "Accept": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/batches/{batch_id}".format(batch_id="batch_id_example"),
            method="GET",
            headers=headers,
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))


if __name__ == "__main__":
    unittest.main()



import unittest

from flask import json

from timestep.api.openai.v1.models.assistant_object import AssistantObject  # noqa: E501
from timestep.api.openai.v1.models.create_assistant_request import (  # noqa: E501
    CreateAssistantRequest,
)
from timestep.api.openai.v1.models.create_message_request import (  # noqa: E501
    CreateMessageRequest,
)
from timestep.api.openai.v1.models.create_run_request import (  # noqa: E501
    CreateRunRequest,
)
from timestep.api.openai.v1.models.create_thread_and_run_request import (  # noqa: E501
    CreateThreadAndRunRequest,
)
from timestep.api.openai.v1.models.create_thread_request import (  # noqa: E501
    CreateThreadRequest,
)
from timestep.api.openai.v1.models.delete_assistant_response import (  # noqa: E501
    DeleteAssistantResponse,
)
from timestep.api.openai.v1.models.delete_message_response import (  # noqa: E501
    DeleteMessageResponse,
)
from timestep.api.openai.v1.models.delete_thread_response import (  # noqa: E501
    DeleteThreadResponse,
)
from timestep.api.openai.v1.models.list_assistants_response import (  # noqa: E501
    ListAssistantsResponse,
)
from timestep.api.openai.v1.models.list_messages_response import (  # noqa: E501
    ListMessagesResponse,
)
from timestep.api.openai.v1.models.list_run_steps_response import (  # noqa: E501
    ListRunStepsResponse,
)
from timestep.api.openai.v1.models.list_runs_response import (  # noqa: E501
    ListRunsResponse,
)
from timestep.api.openai.v1.models.message_object import MessageObject  # noqa: E501
from timestep.api.openai.v1.models.modify_assistant_request import (  # noqa: E501
    ModifyAssistantRequest,
)
from timestep.api.openai.v1.models.modify_message_request import (  # noqa: E501
    ModifyMessageRequest,
)
from timestep.api.openai.v1.models.modify_run_request import (  # noqa: E501
    ModifyRunRequest,
)
from timestep.api.openai.v1.models.modify_thread_request import (  # noqa: E501
    ModifyThreadRequest,
)
from timestep.api.openai.v1.models.run_object import RunObject  # noqa: E501
from timestep.api.openai.v1.models.run_step_object import RunStepObject  # noqa: E501
from timestep.api.openai.v1.models.submit_tool_outputs_run_request import (  # noqa: E501
    SubmitToolOutputsRunRequest,
)
from timestep.api.openai.v1.models.thread_object import ThreadObject  # noqa: E501
from timestep.api.openai.v1.test import BaseTestCase


class TestAssistantsController(BaseTestCase):
    """AssistantsController integration test stubs"""

    def test_cancel_run(self):
        """Test case for cancel_run

        Cancels a run that is `in_progress`.
        """
        headers = {
            "Accept": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/threads/{thread_id}/runs/{run_id}/cancel".format(
                thread_id="thread_id_example", run_id="run_id_example"
            ),
            method="POST",
            headers=headers,
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_create_assistant(self):
        """Test case for create_assistant

        Create an assistant with a model and instructions.
        """
        create_assistant_request = {
            "top_p": 1,
            "instructions": "instructions",
            "tool_resources": {
                "code_interpreter": {
                    "file_ids": [
                        "file_ids",
                        "file_ids",
                        "file_ids",
                        "file_ids",
                        "file_ids",
                    ]
                },
                "file_search": {
                    "vector_store_ids": ["vector_store_ids"],
                    "vector_stores": [
                        {
                            "chunking_strategy": {"type": "auto"},
                            "metadata": "{}",
                            "file_ids": [
                                "file_ids",
                                "file_ids",
                                "file_ids",
                                "file_ids",
                                "file_ids",
                            ],
                        }
                    ],
                },
            },
            "metadata": "{}",
            "response_format": "none",
            "name": "name",
            "temperature": 1,
            "description": "description",
            "model": "gpt-4-turbo",
            "tools": [
                {"type": "code_interpreter"},
                {"type": "code_interpreter"},
                {"type": "code_interpreter"},
                {"type": "code_interpreter"},
                {"type": "code_interpreter"},
            ],
        }
        headers = {
            "Accept": "application/json",
            "Content-Type": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/assistants",
            method="POST",
            headers=headers,
            data=json.dumps(create_assistant_request),
            content_type="application/json",
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_create_message(self):
        """Test case for create_message

        Create a message.
        """
        create_message_request = {
            "metadata": "{}",
            "role": "user",
            "attachments": [
                {
                    "file_id": "file_id",
                    "tools": [
                        {"type": "code_interpreter"},
                        {"type": "code_interpreter"},
                    ],
                },
                {
                    "file_id": "file_id",
                    "tools": [
                        {"type": "code_interpreter"},
                        {"type": "code_interpreter"},
                    ],
                },
            ],
            "content": "CreateMessageRequest_content",
        }
        headers = {
            "Accept": "application/json",
            "Content-Type": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/threads/{thread_id}/messages".format(thread_id="thread_id_example"),
            method="POST",
            headers=headers,
            data=json.dumps(create_message_request),
            content_type="application/json",
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_create_run(self):
        """Test case for create_run

        Create a run.
        """
        create_run_request = {
            "instructions": "instructions",
            "additional_instructions": "additional_instructions",
            "metadata": "{}",
            "assistant_id": "assistant_id",
            "additional_messages": [
                {
                    "metadata": "{}",
                    "role": "user",
                    "attachments": [
                        {
                            "file_id": "file_id",
                            "tools": [
                                {"type": "code_interpreter"},
                                {"type": "code_interpreter"},
                            ],
                        },
                        {
                            "file_id": "file_id",
                            "tools": [
                                {"type": "code_interpreter"},
                                {"type": "code_interpreter"},
                            ],
                        },
                    ],
                    "content": "CreateMessageRequest_content",
                },
                {
                    "metadata": "{}",
                    "role": "user",
                    "attachments": [
                        {
                            "file_id": "file_id",
                            "tools": [
                                {"type": "code_interpreter"},
                                {"type": "code_interpreter"},
                            ],
                        },
                        {
                            "file_id": "file_id",
                            "tools": [
                                {"type": "code_interpreter"},
                                {"type": "code_interpreter"},
                            ],
                        },
                    ],
                    "content": "CreateMessageRequest_content",
                },
            ],
            "tools": [
                {"type": "code_interpreter"},
                {"type": "code_interpreter"},
                {"type": "code_interpreter"},
                {"type": "code_interpreter"},
                {"type": "code_interpreter"},
            ],
            "truncation_strategy": {"last_messages": 1, "type": "auto"},
            "top_p": 1,
            "max_completion_tokens": 256,
            "response_format": "none",
            "parallel_tool_calls": True,
            "stream": True,
            "temperature": 1,
            "tool_choice": "none",
            "model": "gpt-4-turbo",
            "max_prompt_tokens": 256,
        }
        headers = {
            "Accept": "application/json",
            "Content-Type": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/threads/{thread_id}/runs".format(thread_id="thread_id_example"),
            method="POST",
            headers=headers,
            data=json.dumps(create_run_request),
            content_type="application/json",
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_create_thread(self):
        """Test case for create_thread

        Create a thread.
        """
        create_thread_request = {
            "tool_resources": {
                "code_interpreter": {
                    "file_ids": [
                        "file_ids",
                        "file_ids",
                        "file_ids",
                        "file_ids",
                        "file_ids",
                    ]
                },
                "file_search": {
                    "vector_store_ids": ["vector_store_ids"],
                    "vector_stores": [
                        {
                            "chunking_strategy": {"type": "auto"},
                            "metadata": "{}",
                            "file_ids": [
                                "file_ids",
                                "file_ids",
                                "file_ids",
                                "file_ids",
                                "file_ids",
                            ],
                        }
                    ],
                },
            },
            "metadata": "{}",
            "messages": [
                {
                    "metadata": "{}",
                    "role": "user",
                    "attachments": [
                        {
                            "file_id": "file_id",
                            "tools": [
                                {"type": "code_interpreter"},
                                {"type": "code_interpreter"},
                            ],
                        },
                        {
                            "file_id": "file_id",
                            "tools": [
                                {"type": "code_interpreter"},
                                {"type": "code_interpreter"},
                            ],
                        },
                    ],
                    "content": "CreateMessageRequest_content",
                },
                {
                    "metadata": "{}",
                    "role": "user",
                    "attachments": [
                        {
                            "file_id": "file_id",
                            "tools": [
                                {"type": "code_interpreter"},
                                {"type": "code_interpreter"},
                            ],
                        },
                        {
                            "file_id": "file_id",
                            "tools": [
                                {"type": "code_interpreter"},
                                {"type": "code_interpreter"},
                            ],
                        },
                    ],
                    "content": "CreateMessageRequest_content",
                },
            ],
        }
        headers = {
            "Accept": "application/json",
            "Content-Type": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/threads",
            method="POST",
            headers=headers,
            data=json.dumps(create_thread_request),
            content_type="application/json",
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_create_thread_and_run(self):
        """Test case for create_thread_and_run

        Create a thread and run it in one request.
        """
        create_thread_and_run_request = {
            "instructions": "instructions",
            "tool_resources": {
                "code_interpreter": {
                    "file_ids": [
                        "file_ids",
                        "file_ids",
                        "file_ids",
                        "file_ids",
                        "file_ids",
                    ]
                },
                "file_search": {"vector_store_ids": ["vector_store_ids"]},
            },
            "metadata": "{}",
            "assistant_id": "assistant_id",
            "thread": {
                "tool_resources": {
                    "code_interpreter": {
                        "file_ids": [
                            "file_ids",
                            "file_ids",
                            "file_ids",
                            "file_ids",
                            "file_ids",
                        ]
                    },
                    "file_search": {
                        "vector_store_ids": ["vector_store_ids"],
                        "vector_stores": [
                            {
                                "chunking_strategy": {"type": "auto"},
                                "metadata": "{}",
                                "file_ids": [
                                    "file_ids",
                                    "file_ids",
                                    "file_ids",
                                    "file_ids",
                                    "file_ids",
                                ],
                            }
                        ],
                    },
                },
                "metadata": "{}",
                "messages": [
                    {
                        "metadata": "{}",
                        "role": "user",
                        "attachments": [
                            {
                                "file_id": "file_id",
                                "tools": [
                                    {"type": "code_interpreter"},
                                    {"type": "code_interpreter"},
                                ],
                            },
                            {
                                "file_id": "file_id",
                                "tools": [
                                    {"type": "code_interpreter"},
                                    {"type": "code_interpreter"},
                                ],
                            },
                        ],
                        "content": "CreateMessageRequest_content",
                    },
                    {
                        "metadata": "{}",
                        "role": "user",
                        "attachments": [
                            {
                                "file_id": "file_id",
                                "tools": [
                                    {"type": "code_interpreter"},
                                    {"type": "code_interpreter"},
                                ],
                            },
                            {
                                "file_id": "file_id",
                                "tools": [
                                    {"type": "code_interpreter"},
                                    {"type": "code_interpreter"},
                                ],
                            },
                        ],
                        "content": "CreateMessageRequest_content",
                    },
                ],
            },
            "tools": [
                {"type": "code_interpreter"},
                {"type": "code_interpreter"},
                {"type": "code_interpreter"},
                {"type": "code_interpreter"},
                {"type": "code_interpreter"},
            ],
            "truncation_strategy": {"last_messages": 1, "type": "auto"},
            "top_p": 1,
            "max_completion_tokens": 256,
            "response_format": "none",
            "parallel_tool_calls": True,
            "stream": True,
            "temperature": 1,
            "tool_choice": "none",
            "model": "gpt-4-turbo",
            "max_prompt_tokens": 256,
        }
        headers = {
            "Accept": "application/json",
            "Content-Type": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/threads/runs",
            method="POST",
            headers=headers,
            data=json.dumps(create_thread_and_run_request),
            content_type="application/json",
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_delete_assistant(self):
        """Test case for delete_assistant

        Delete an assistant.
        """
        headers = {
            "Accept": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/assistants/{assistant_id}".format(assistant_id="assistant_id_example"),
            method="DELETE",
            headers=headers,
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_delete_message(self):
        """Test case for delete_message

        Deletes a message.
        """
        headers = {
            "Accept": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/threads/{thread_id}/messages/{message_id}".format(
                thread_id="thread_id_example", message_id="message_id_example"
            ),
            method="DELETE",
            headers=headers,
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_delete_thread(self):
        """Test case for delete_thread

        Delete a thread.
        """
        headers = {
            "Accept": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/threads/{thread_id}".format(thread_id="thread_id_example"),
            method="DELETE",
            headers=headers,
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_get_assistant(self):
        """Test case for get_assistant

        Retrieves an assistant.
        """
        headers = {
            "Accept": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/assistants/{assistant_id}".format(assistant_id="assistant_id_example"),
            method="GET",
            headers=headers,
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_get_message(self):
        """Test case for get_message

        Retrieve a message.
        """
        headers = {
            "Accept": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/threads/{thread_id}/messages/{message_id}".format(
                thread_id="thread_id_example", message_id="message_id_example"
            ),
            method="GET",
            headers=headers,
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_get_run(self):
        """Test case for get_run

        Retrieves a run.
        """
        headers = {
            "Accept": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/threads/{thread_id}/runs/{run_id}".format(
                thread_id="thread_id_example", run_id="run_id_example"
            ),
            method="GET",
            headers=headers,
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_get_run_step(self):
        """Test case for get_run_step

        Retrieves a run step.
        """
        headers = {
            "Accept": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/threads/{thread_id}/runs/{run_id}/steps/{step_id}".format(
                thread_id="thread_id_example",
                run_id="run_id_example",
                step_id="step_id_example",
            ),
            method="GET",
            headers=headers,
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_get_thread(self):
        """Test case for get_thread

        Retrieves a thread.
        """
        headers = {
            "Accept": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/threads/{thread_id}".format(thread_id="thread_id_example"),
            method="GET",
            headers=headers,
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_list_assistants(self):
        """Test case for list_assistants

        Returns a list of assistants.
        """
        query_string = [
            ("limit", 20),
            ("order", desc),
            ("after", "after_example"),
            ("before", "before_example"),
        ]
        headers = {
            "Accept": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/assistants", method="GET", headers=headers, query_string=query_string
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_list_messages(self):
        """Test case for list_messages

        Returns a list of messages for a given thread.
        """
        query_string = [
            ("limit", 20),
            ("order", desc),
            ("after", "after_example"),
            ("before", "before_example"),
            ("run_id", "run_id_example"),
        ]
        headers = {
            "Accept": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/threads/{thread_id}/messages".format(thread_id="thread_id_example"),
            method="GET",
            headers=headers,
            query_string=query_string,
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_list_run_steps(self):
        """Test case for list_run_steps

        Returns a list of run steps belonging to a run.
        """
        query_string = [
            ("limit", 20),
            ("order", desc),
            ("after", "after_example"),
            ("before", "before_example"),
        ]
        headers = {
            "Accept": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/threads/{thread_id}/runs/{run_id}/steps".format(
                thread_id="thread_id_example", run_id="run_id_example"
            ),
            method="GET",
            headers=headers,
            query_string=query_string,
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_list_runs(self):
        """Test case for list_runs

        Returns a list of runs belonging to a thread.
        """
        query_string = [
            ("limit", 20),
            ("order", desc),
            ("after", "after_example"),
            ("before", "before_example"),
        ]
        headers = {
            "Accept": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/threads/{thread_id}/runs".format(thread_id="thread_id_example"),
            method="GET",
            headers=headers,
            query_string=query_string,
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_modify_assistant(self):
        """Test case for modify_assistant

        Modifies an assistant.
        """
        modify_assistant_request = {
            "top_p": 1,
            "instructions": "instructions",
            "tool_resources": {
                "code_interpreter": {
                    "file_ids": [
                        "file_ids",
                        "file_ids",
                        "file_ids",
                        "file_ids",
                        "file_ids",
                    ]
                },
                "file_search": {"vector_store_ids": ["vector_store_ids"]},
            },
            "metadata": "{}",
            "response_format": "none",
            "name": "name",
            "temperature": 1,
            "description": "description",
            "model": "model",
            "tools": [
                {"type": "code_interpreter"},
                {"type": "code_interpreter"},
                {"type": "code_interpreter"},
                {"type": "code_interpreter"},
                {"type": "code_interpreter"},
            ],
        }
        headers = {
            "Accept": "application/json",
            "Content-Type": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/assistants/{assistant_id}".format(assistant_id="assistant_id_example"),
            method="POST",
            headers=headers,
            data=json.dumps(modify_assistant_request),
            content_type="application/json",
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_modify_message(self):
        """Test case for modify_message

        Modifies a message.
        """
        modify_message_request = {"metadata": "{}"}
        headers = {
            "Accept": "application/json",
            "Content-Type": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/threads/{thread_id}/messages/{message_id}".format(
                thread_id="thread_id_example", message_id="message_id_example"
            ),
            method="POST",
            headers=headers,
            data=json.dumps(modify_message_request),
            content_type="application/json",
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_modify_run(self):
        """Test case for modify_run

        Modifies a run.
        """
        modify_run_request = {"metadata": "{}"}
        headers = {
            "Accept": "application/json",
            "Content-Type": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/threads/{thread_id}/runs/{run_id}".format(
                thread_id="thread_id_example", run_id="run_id_example"
            ),
            method="POST",
            headers=headers,
            data=json.dumps(modify_run_request),
            content_type="application/json",
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_modify_thread(self):
        """Test case for modify_thread

        Modifies a thread.
        """
        modify_thread_request = {
            "tool_resources": {
                "code_interpreter": {
                    "file_ids": [
                        "file_ids",
                        "file_ids",
                        "file_ids",
                        "file_ids",
                        "file_ids",
                    ]
                },
                "file_search": {"vector_store_ids": ["vector_store_ids"]},
            },
            "metadata": "{}",
        }
        headers = {
            "Accept": "application/json",
            "Content-Type": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/threads/{thread_id}".format(thread_id="thread_id_example"),
            method="POST",
            headers=headers,
            data=json.dumps(modify_thread_request),
            content_type="application/json",
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))

    def test_submit_tool_ouputs_to_run(self):
        """Test case for submit_tool_ouputs_to_run

        When a run has the `status: \"requires_action\"` and `required_action.type` is `submit_tool_outputs`, this endpoint can be used to submit the outputs from the tool calls once they're all completed. All outputs must be submitted in a single request.
        """
        submit_tool_outputs_run_request = {
            "stream": True,
            "tool_outputs": [
                {"output": "output", "tool_call_id": "tool_call_id"},
                {"output": "output", "tool_call_id": "tool_call_id"},
            ],
        }
        headers = {
            "Accept": "application/json",
            "Content-Type": "application/json",
            "Authorization": "Bearer special-key",
        }
        response = self.client.open(
            "/v1/threads/{thread_id}/runs/{run_id}/submit_tool_outputs".format(
                thread_id="thread_id_example", run_id="run_id_example"
            ),
            method="POST",
            headers=headers,
            data=json.dumps(submit_tool_outputs_run_request),
            content_type="application/json",
        )
        self.assert200(response, "Response body is : " + response.data.decode("utf-8"))


if __name__ == "__main__":
    unittest.main()
